@@ -1,4 +1,7 @@
 #include "WebFormat.h"
+#include <unistd.h>
+#include <signal.h>
+#include <new>
 
 using namespace magics;
 
@@ -41,13 +44,26 @@ void setVariable(const string& in, map<string, string>& variables)
 
 } //end of namespace magml
 
+void catch_alarm(int)
+{
+    Log::error() << "Operation timed out. Exiting...\n";
+    exit(1);   
+}
+
+void no_memory () {
+    Log::error() << "Failed to allocate memory!\n";
+    exit (1);
+}
+
+
 int main(int argc, char **argv)
 {
+    set_new_handler(no_memory);
     try
     {
 	    if(argc<2)
 	    {
-		    Log::error() << " Usage: " << argv[0] << " file.magml [-varname=varvalue]\n";		   
+		    Log::error() << " Usage: " << argv[0] << " file.magml [-varname=varvalue] -timeout=seconds)\n";		   
 		    exit (1);
 	    }
 
@@ -60,7 +76,14 @@ int main(int argc, char **argv)
 	{
 		
         try {
-		    WebInterpretor::magml(argv[1]);
+            
+            map<string, string>::const_iterator out = WebInterpretor::parameters().find("timeout");
+            int timeout = (out == WebInterpretor::parameters().end() ) ? 0 : tonumber(out->second);
+		    Log::info() << "Time out armed for " << timeout << endl; 
+            signal(SIGALRM, catch_alarm);
+            alarm(timeout); 
+            WebInterpretor::magml(argv[1]);
+            alarm(0);
 		
 	    }
         catch (...) {
