@@ -28,7 +28,7 @@
 */
 
 
-
+#include "magics_ecmwf_log.h"
 #include "FortranMagics.h"
 #include "Timer.h"
 
@@ -62,6 +62,7 @@
 
 #include "ImportAction.h"
 #include "ImportPlot.h"
+#include "ImportObjectHandler.h"
 
 #ifdef MAGICS_BUFR
 #include "ObsPlotting.h"
@@ -257,7 +258,7 @@ void FortranMagics::plegend()
     	legend(); // force the legend to be added! 
 }
 
-void FortranMagics::pimport()
+void FortranMagics::poverlay()
 {    
 	actions();		
 	
@@ -283,6 +284,14 @@ void FortranMagics::pimport()
 	
 	
 }
+void FortranMagics::pimport()
+{
+	
+	
+	ImportObjectHandler* object = new ImportObjectHandler();
+	
+	later_.push_back(object);
+}
 
 
 void FortranMagics::pnew(const string& type)
@@ -395,7 +404,11 @@ void FortranMagics::finish()
 	// Check any text	
 	
     
-	
+	for (vector<BasicSceneObject* >::iterator other = later_.begin();  other != later_.end(); ++other) {
+					top()->push_back(*other);
+					
+				}
+				later_.clear();
 	
 	for (vector<FortranTextVisitor* >::iterator text = texts_.begin();  text != texts_.end(); ++text) {
 					top()->text(*text);
@@ -480,9 +493,15 @@ void FortranMagics::pimage()
 
 }
 
+#include "OdaDecoder.h"
 
 void FortranMagics::podb()
 {
+#ifdef MAGICS_ODB
+	geoaction_ = new VisualAction<GeoPoint>();
+	geoaction_->data(new OdaDecoder());
+    top()->push_back(geoaction_);
+#endif
 }
 
 
@@ -745,7 +764,7 @@ void FortranMagics::pgraph()
 
  	GraphPlotting* graph = new GraphPlotting();
 	top()->push_back(xyaction_);
-	XYList* input = new XYList();	
+	XYList<UserPoint>* input = new XYList<UserPoint>();	
 	xyaction_->data(input);
 	Log::dev() << *input << "\n";   
 	xyaction_->visdef(graph);
