@@ -24,6 +24,7 @@
 
 */
 
+#include "magics_ecmwf_log.h"
 #include "XmlMagics.h"
 #include "XmlReader.h"
 #include "Exception.h"
@@ -33,6 +34,8 @@
 #include "SceneNode.h"
 #include "ViewNode.h"
 #include "Coastlines.h"
+#include "BinaryObject.h"
+
 #include "TaylorGrid.h"
 #include "GribDecoder.h"
 #include "NetcdfDecoder.h"
@@ -85,6 +88,8 @@ XmlMagics::XmlMagics() : root_(0),
 
 	actions_["magics"] = &XmlMagics::magics;
 	actions_["page"] = &XmlMagics::page;
+	
+	actions_["binary"] = &XmlMagics::binary;
 
 	actions_["text"] = &XmlMagics::text;
 	actions_["map"] = &XmlMagics::map;
@@ -101,8 +106,8 @@ XmlMagics::XmlMagics() : root_(0),
 
 	actions_["grib"] = &XmlMagics::grib;
 	actions_["netcdf"] = &XmlMagics::netcdf;
-	actions_["odb"] = &XmlMagics::odb;
-	actions_["oda"] = &XmlMagics::oda;
+
+	actions_["odb"] = &XmlMagics::oda;
 	actions_["xyinput"] = &XmlMagics::xyinput;
 	actions_["landgram"] = &XmlMagics::landgram;
 
@@ -164,36 +169,37 @@ void XmlMagics::print(ostream& out)  const
 void XmlMagics::execute(XmlTree& tree) 
 {
 	try {
-			
-			tree.visit(*this);
-		}
-		catch (MagicsException& e) {
-				Log::debug() << e.what() << endl;
-		}
-		
-		if ( driversToSet_ ) 
-			output_.set(drivers_);
+		tree.visit(*this);
+	}
+	catch (MagicsException& e) {
+		Log::debug() << e.what() << endl;
+	}
 
-		assert(root_);
-		
-		
-		
-		root_->execute();
-		
-		drivers_.setDriversWidth(root_->absoluteWidth());
-		drivers_.setDriversHeight(root_->absoluteHeight());
-			
-		{ 
-			Timer timer("Render Grpahical tree-->");
-			drivers_.openDrivers();
-			drivers_.dispatch(root_->root());
-			
-			drivers_.closeDrivers();
-		}
+	if ( driversToSet_ ) 
+		output_.set(drivers_);
 
-		MetaDataVisitor::collect();
-		//root_->metadata(meta);
-		/* later 
+	assert(root_);
+
+	root_->execute();
+
+	if ( root_->scalingFactor() != 1)  
+		drivers_.setOutputWidth(root_->scalingFactor());
+
+
+	drivers_.setDriversWidth(root_->absoluteWidth());
+	drivers_.setDriversHeight(root_->absoluteHeight());
+
+	{ 
+		Timer timer("drivers", "rendering of the graphical tree");
+		drivers_.openDrivers();
+		drivers_.dispatch(root_->root());
+
+		drivers_.closeDrivers();
+	}
+
+	MetaDataVisitor::collect();
+	//root_->metadata(meta);
+	/* later 
 		std::map<string, string>::const_iterator filename = meta.find("filename");
 		if ( filename != meta.end() && !filename->second.empty()) {
 			ofstream file (filename->second.c_str());
@@ -203,12 +209,11 @@ void XmlMagics::execute(XmlTree& tree)
 	                file << d->first << " = " << d->second << "; " << endl;
 	        }
 		}
-		*/
-		output_.clear();
-		//ParameterManager::release();
-		delete root_;
-		root_ = 0;
-	
+	*/
+	output_.clear();
+	//ParameterManager::release();
+	delete root_;
+	root_ = 0;
 }
 
 void XmlMagics::execute(const string& file, std::map<string, string>& )
@@ -249,7 +254,7 @@ void XmlMagics::display(const string& file)
 	root_->execute();
 	drivers_.openDrivers();
 	drivers_.dispatch(root_->root());
-			
+
 	drivers_.closeDrivers();
 }
 	
@@ -267,11 +272,11 @@ void XmlMagics::visit(const XmlNode& node)
 
 void XmlMagics::magics(const XmlNode& node)
 {
-	root_ = new XmlRootSceneNode();
 	float version_ = 3.0;
 	Log::debug() << " You are using the " << fixed << setprecision(1) << version_ << " version of the magml interpreter\n";
 	string version = node.getAttribute("version");
-	if ( version.empty() ) {
+	if ( version.empty() )
+	{
 		Log::error() << " No version defined in your magml file" << endl;
 		Log::error() << " Compatibilty issue : check your magml file and add a version number" << endl;
 		return;
@@ -279,11 +284,17 @@ void XmlMagics::magics(const XmlNode& node)
 	float v;
 	std::stringstream sv(version);
 	sv >> v;
-	if ( v < version_ ) {
+	if ( v < version_ )
+	{
 		Log::error() << " The version defined in the file is " << fixed << setprecision(1) << v << endl;
 		Log::error() << " Compatibilty issue : check your magml file and update the version number " << endl;
 		return;
 	}
+	string method = node.getAttribute("method") ;
+	
+	root_ =  ( method == "wrep" ) ? new  WrepRootSceneNode() : new  XmlRootSceneNode();
+	
+	
 	push(root_);
 	root_->set(node);
 	root_->getReady();
@@ -357,6 +368,7 @@ void XmlMagics::metadata(const XmlNode& node)
 void XmlMagics::page(const XmlNode& node)
 {
 	XmlSceneNode* page = new XmlSceneNode();
+
 	page->set(node);
 	top()->insert(page);
 	push(page);
@@ -396,6 +408,12 @@ void XmlMagics::map(const XmlNode& node)
 	pop();
 }
 
+void XmlMagics::binary(const XmlNode& node)
+{	
+	BinaryObject* binary = new BinaryObject();
+	binary->set(node);
+	top()->push_back(binary);
+}
 
 void XmlMagics::coastlines(const XmlNode& node)
 {	
@@ -497,8 +515,7 @@ void XmlMagics::gribinloop(const XmlNode&)
 
 
 void XmlMagics::grib(const XmlNode& node)
-{	
-	
+{
 	GribDecoder* grib = new GribDecoder();
 	grib->set(node);
 	if (geographical_) {
@@ -527,9 +544,16 @@ void XmlMagics::mapgen(const XmlNode& node)
 
 void XmlMagics::xyinput(const XmlNode& node)
 {	
-	XYList* list = new XYList();
-	list->set(node);
-	top()->data(list);
+	if (geographical_) {
+			XYList<GeoPoint>* list = new XYList<GeoPoint>();
+			list->set(node);
+			top()->data(list);
+	}
+	else {
+			XYList<UserPoint>* list = new XYList<UserPoint>();
+			list->set(node);
+			top()->data(list);
+	}
 }
 
 void XmlMagics::landgram(const XmlNode& node)
@@ -545,63 +569,50 @@ void XmlMagics::landgrambox(const XmlNode& node)
 	box->set(node);
 	top()->visdef(box);
 }
-#include "GraphPlotting.h"
 
-void XmlMagics::graph(const XmlNode& /*node*/)
+#include "GraphPlotting.h"
+void XmlMagics::graph(const XmlNode& node)
 {	
-	/*
 	GraphPlotting* graph =  new GraphPlotting();
 	graph->set(node);
 	top()->visdef(graph);
-	*/
 }
 
 void XmlMagics::histogram(const XmlNode& node)
-{	
-	
+{
 	Histogram* histogram =  new Histogram();
 	histogram->set(node);
 	top()->visdef(histogram);
-	
 }
 
-extern "C"{
-//! This function is overwritten in libMagPlusODB
-Data<GeoPoint>* callodb(const XmlNode& )
+
+/***************************************************************************
+
+    O D B / O D A
+
+***************************************************************************/
+
+
+
+void XmlMagics::odb(const XmlNode& )
 {
-	Log::warning() << "ODB support is NOT enabled! (Forgotten -lMagPlusODB ?)\n";
-	return 0;
-}
-
-//! This function is overwritten in libMagPlusODB
-Data<GeoPoint>* calloda(const XmlNode& )
-{
-	Log::warning() << "ODB support is NOT enabled! (Forgotten -lMagPlusODB ?)\n";
-	return 0;
-}
-}
-
-#ifdef MAGICS_ODB
-void XmlMagics::odb(const XmlNode& node)
-{	
-    top()->data(callodb(node));
 }
 #include "OdaDecoder.h"
+
 void XmlMagics::oda(const XmlNode& node)
-{	
-    OdaDecoder* oda =  new OdaDecoder();
-    oda->set(node);
-    top()->data(oda);
-}
-#else
-void XmlMagics::odb(const XmlNode&)
 {
+#ifdef MAGICS_ODB
+
+	OdaDecoder* oda = new OdaDecoder();
+	oda->set(node);
+    top()->data(oda);
+#else 
+	Log::warning() << "ODB support is NOT enabled! (Forgotten -lMagPlusODB ?)\n";
+#endif
+
 }
 
-void XmlMagics::oda(const XmlNode& )
-{
-}
-#endif
+/* ********************************************************************* */
 
 
 void XmlMagics::efigram(const XmlNode& node)
@@ -612,6 +623,7 @@ void XmlMagics::efigram(const XmlNode& node)
 	top()->data(efi);
 #endif
 }
+
 void XmlMagics::efigraph(const XmlNode& node)
 {	
 #ifdef MAGICS_SPOT
@@ -620,6 +632,7 @@ void XmlMagics::efigraph(const XmlNode& node)
 	top()->visdef(efi);
 #endif
 }
+
 void XmlMagics::epsplume(const XmlNode& node)
 {	
 #ifdef MAGICS_SPOT
@@ -628,6 +641,7 @@ void XmlMagics::epsplume(const XmlNode& node)
 	top()->visdef(plume);
 #endif
 }
+
 void XmlMagics::epsdirection(const XmlNode& node)
 {	
 #ifdef MAGICS_SPOT
