@@ -591,7 +591,11 @@ void ptest_()
 //! This function is overwritten in libMagPlusODB
 void podb_()
 {
+#ifdef MAGICS_ODB
+	magics_->podb();
+#else
 	Log::warning() << "ODB support is NOT enabled! (Please try linking -lMagPlusODB)\n";
+#endif
 }
 
 
@@ -599,7 +603,10 @@ void pimport_()
 {
 	magics_->pimport();
 }
-
+void poverlay_()
+{
+	magics_->poverlay();
+}
 void pnetcdf_()
 {
 	magics_->pnetcdf();
@@ -631,13 +638,13 @@ void pimage_()
 
 void pplot_()
 {
-   Log::info() << "pplot has no effect ... use pimport instead" << endl;;  
-    
+	Log::warning() << "pplot has no effect ... use pimport instead" << endl;
 }
 
-void pnew_(const char* page, int l)
+void pnew_(const char* name, int length)
 {
-	magics_->pnew(string(page, l));
+	std::string n(name, length);
+	mag_new(n.c_str());
 }
 
 void ptext_()
@@ -658,7 +665,7 @@ void pline_()
 
 void psymb_()
 {
-    magics_->psymb();
+	magics_->psymb();
 }
 
 void pclose_()
@@ -671,27 +678,23 @@ void pclose_()
 
 void pact_(const char*, const char*, const char*, int, int, int)
 {
-	Log::dev() << "entry in the new pact [NOT implemented ]\n";    
+	Log::dev() << "PACT will NOT be implemented!\n";    
 }
 
-void preset_(const char* name, int namel)
+void preset_(const char* name, int length)
 {
-	try {
-		ParameterManager::reset(string(name, namel));
-	}
-	catch (MagicsException& e)
-	{
-		Log::error() << e << "\n";
-	}
+	std::string n(name, length);
+	mag_reset(n.c_str());
 }
 
 void psetc_(const char* name, const char* value, int namel, int valuel)
 {
 	try {        
 		string val = string(value, valuel);
-		int index = val.find_last_not_of(" ");    
-		if ( CompatibilityHelper::check(string(name, namel), val.substr(0, index+1)) ) return;
-		ParameterManager::set(string(name, namel), val.substr(0, index+1));
+		string::size_type index = val.find_last_not_of(" ");    
+		val = (index == string::npos) ? "" :  val.substr(0, index+1);
+		if ( CompatibilityHelper::check(string(name, namel), val) ) return;
+		ParameterManager::set(string(name, namel), val);
 	}
 	catch (MagicsException& e)
 	{
@@ -711,43 +714,39 @@ void pseti_(const char* name, const int* value, int namel)
 	}
 }
 
-void pset1i_(const char* name, const int* value, const int* dim, int nl)
+void pset1i_(const char* name, const int* data, const int* dim, int length)
 {
-	Log::dev() << "entry in the new pset1i\n";    
-	intarray values;
-	for ( int i = 0; i < *dim; i++) values.push_back(value[i]);        
-
-	try {
-		ParameterManager::set(string(name, nl), values);
-	}
-	catch (MagicsException& e)
-	{
-		Log::error() << e << "\n";
-	}
+	std::string n(name, length);
+	mag_set1i(n.c_str(), data, *dim);
 }
 
-void pset2i_(const char*, const int*, const int*, const int*, int)
+void pset2i_(const char* name, const int* data, const int* dim, const int* dim2, int length)
 {
-	Log::warning() << "pset2i-->not yet implemented\n";    
+	std::string n(name, length);
+	mag_set2i(n.c_str(), data, *dim, *dim2);	    
 }
 
-void pset3i_(const char*, const int*, const int*, const int*, const int*, int)
+void pset3i_(const char* name, const int* data, const int* dim, const int* dim2, const int* dim3, int length)
 {
-	Log::warning() << "pset3i-->not yet implemented\n";      
+	std::string n(name, length);
+	mag_set3i(n.c_str(), data, *dim, *dim2, *dim3);	     
 }
 
 void pset1c_(const char* name, const char* value, const int *dim, int namel, int l)
 {
-    Log::dev() << "entry in the new pset1c\n";    
-    Log::dev() << "\tpset1c(\"" << string(name, namel) << ", "  << value << ", "  << *dim << ", " << l << ");"  << "\n";
     stringarray values;
     string work(value, (*dim)*l);
     int first =0;
     for ( int i = 0; i < *dim; i++) {
+    	
         // remove the  space at the end of the string
         string val = work.substr(first, l);
-        int index = val.find_last_not_of(" ");
-        values.push_back(val.substr(0, index+1));        
+        
+        string::size_type index = val.find_last_not_of(" ");
+        if (index == string::npos)
+        	 values.push_back("");
+        else 
+        	values.push_back(val.substr(0, index+1));        
         first += l;
     }
     
@@ -763,27 +762,26 @@ void pset1c_(const char* name, const char* value, const int *dim, int namel, int
 }
 
 
-void penqi_(const char* name, int* value, int namel)
+void penqi_(const char* name, int* value)
 {
-	Log::dev() << "entry in the new penqi\n";    
-	Log::dev() << "\tpenqi(\"" << string(name, namel) << "\", "  << *value << ");"  << "\n";
+	mag_enqi( name, value);
 }
 
-void penqc_(const char* name, char* value, int namel, int valuel)
+
+void penqc_(const char* name, char* value)
 {
-	Log::dev() << "entry in the new penqc\n";    
-	Log::dev() << "\tpenqc(\"" << string(name, namel) << "\", \"" << string(value, valuel) << "\");"  << "\n";
+	mag_enqc( name, value);
 }
 
 void ppie_()
 {
-	Log::warning() << "ppie-->not yet implemented\n";   
+	Log::warning() << "ppie-> is deprecated and will NOT be implemented.\n";   
 }
 
 
 void pgraph_()
 {
-    magics_->pgraph();
+	magics_->pgraph();
 }
 
 void paxis_()
@@ -830,6 +828,7 @@ void mag_grib()  {pgrib_();}
 void mag_test()  {ptest_();}
 void mag_odb()   {podb_();}
 void mag_import(){pimport_();}
+void mag_overlay(){poverlay_();}
 void mag_netcdf(){pnetcdf_();}
 void mag_cont()  {pcont_();}
 void mag_obs()   {pobs_();}
@@ -843,14 +842,18 @@ void mag_boxplot()  {pboxplot_();}
 
 void mag_new(const char* page)
 {
-	string n(page);
-	pnew_(n.c_str(), n.size());
+	magics_->pnew(page);
 }
 
 void mag_reset(const char* name)
 {
-	string n(name);
-	preset_(n.c_str(), n.size());	
+	try {
+		ParameterManager::reset(name);
+	}
+	catch (MagicsException& e)
+	{
+		Log::error() << e << "\n";
+	}	
 }
 
 void mag_setc(const char* name, const char* value)
@@ -888,7 +891,14 @@ void mag_setp(const char* name, void* value)
        ParameterManager::set("output_cairo_drawing_context", (CairoPtr)value); 
     }
 #endif
-	
+#ifdef MAGICS_QT
+    if ( magCompare(n, "output_qt_widget") ) {
+       ParameterManager::set("output_qt_widget", (QWidgetPtr)value); 
+    }
+    if ( magCompare(n, "output_qt_scene") ) {
+       ParameterManager::set("output_qt_scene", (QGraphicsScenePtr)value); 
+    }	
+#endif
 }
 void mag_act(const char* a, const char* b, const char* c)
 {
@@ -926,42 +936,56 @@ void mag_set2r(const char* name, const double *data, const int dim1, const int d
 
 void mag_set3r(const char*, const double *, const int, const int, const int)
 {
-	Log::warning() << "pset3r --> not yet implemented\n";      
+	Log::warning() << "pset3r --> not yet implemented\n";
 }
 
 void mag_set1i(const char* name, const int *data, const int dim1)
 {
-	string n(name);
-	pset1i_(name, data, &dim1, n.size());
+	std::string n(name);
+	intarray values;
+	for ( int i = 0; i < dim1; i++) values.push_back(data[i]);        
+
+	try {
+		ParameterManager::set(n, values);
+	}
+	catch (MagicsException& e)
+	{
+		Log::error() << e << "\n";
+	}
 }
 
 void mag_set2i(const char* name, const int *data, const int dim1, const int dim2)
 {
-	string n(name);
-	pset2i_(name, data, &dim1, &dim2, n.size());
+	Matrix matrix;
+	for (int i = 0; i < (dim2) * (dim1); i++) matrix.push_back(data[i]);
+
+	matrix.set(dim2, dim1);
+	ParameterManager::set(string(name), matrix);
+	Log::dev() << "Parameter " << string(name) << " set to " << matrix << "\n";
 }
 
-void mag_set3i(const char* name, const int *data, const int dim1, const int dim2, const int dim3)
+void mag_set3i(const char* , const int *, const int , const int , const int )
 {
-	string n(name);
-	pset3i_(name, data, &dim1, &dim2, &dim3, n.size());
+	Log::warning() << "pset3i --> not yet implemented\n";
 }
 
 void mag_set1c(const char* name, const char** data, const int dim)
 {
 	string n(name);
 
-	Log::dev() << "entry in the new mag_set1c\n";    
-	Log::dev() << "\tmag_set1c("  << dim << " entries);\n";
+//	Log::dev() << "entry in the new mag_set1c\n";    
+//	Log::dev() << "\tmag_set1c("  << dim << " entries);\n";
 	stringarray values;
 
 	for ( int i = 0; i < dim; i++)
 	{
 		string work (data[i]);
 		// remove the space at the start and end of the string
-		int index1 = work.find_first_not_of(" ");
-		int index2 = work.find_last_not_of(" ");
-		values.push_back(work.substr(index1, index2+1));        
+
+		string::size_type index1 = work.find_first_not_of(" ");
+		string::size_type index2 = work.find_last_not_of(" ");
+		string val =  (index1 == string::npos || index2 == string::npos) ? "" : work.substr(index1, index2+1);
+		values.push_back(val);        
 	}
     
 	try {
@@ -984,15 +1008,17 @@ void mag_enqr(const char* name, double *value)
 
 void mag_enqi(const char* name, int *value)
 {
-	string n(name);
-	penqi_(name, value, n.size());
+	int magics;
+	ParameterManager::get(string(name),magics);
+	*value=magics;
 }
 
 void mag_enqc(const char* name, char* value)
 {
-	string n(name);
-	string v(value);
-	penqc_(name, value, n.size(), v.size());
+	string magics;
+	ParameterManager::get(string(name),magics);
+	strcpy( value, magics.c_str() );
+	cout << " ::: "<< string(name)<<" ->> "<<magics<<"    "<< value << endl;
 }
 
 
@@ -1002,11 +1028,11 @@ void mag_axis()  {paxis_();}
 void mag_geo()   {pgeo_();}
 void mag_eps()   {peps_();}
 void mag_print() {pprint_();}
+
 void mag_info()
 {
 	Log::userInfo() << "INFO:\n"
-		<< "INFO: "<<getMagicsRelease()<<"\n"
-		<< "INFO: "<<getMagicsConfigureInfo()<<"\n"
+		<< "INFO: "<<getMagicsVersionString()<<"\n"
 		<< "INFO:\n"
 		<< "INFO: Machine: "<<getEnvVariable("HOSTNAME")<<" is running "<<getEnvVariable("VENDOR")<<" "<<getEnvVariable("OSTYPE")<<" "<<getEnvVariable("MACHTYPE")<<"\n"
 		<< "INFO:\n"
