@@ -181,7 +181,6 @@ public :
             double da = (v2-i)/(v2-v1);
             double db = (i-v1)/(v2-v1);
             double val = (a*da) + (b*db);
-            //Log::debug() << a << "*" << da << "+" << b << "*" << db << "=" << val << "\n";
             return val;
         }
         int jj = columnIndex(j);
@@ -237,11 +236,13 @@ public :
         if (points_.empty()) {
         	int nb_rows = rows();
         	int nb_columns = columns();
+            
+            points_.reserve(nb_rows * nb_columns);
         	
             for (int r = 0; r < nb_rows; r++) {
                 for (int c = 0; c < nb_columns; c++) {
                     if ( matrix_.accept(column(r, c), row(r, c)) ) 
-                        if ( (*this)(r, c) != matrix_.missing() ) 
+                        if ( !same((*this)(r, c), matrix_.missing() ) ) 
                         	points_.push_back(new P(column(r,c), row(r,c), (*this)(r, c)));
                 }
             }            
@@ -314,233 +315,14 @@ protected:
 };
 
 
-template <class P>
-class RegularInterpolator : public MatrixHandler<P>
-{
-public:
-   RegularInterpolator(AbstractMatrix& matrix) : 
-        MatrixHandler<P>(matrix) 
-   {
-   }
-   
-    void setRowsAxis(double from, double to, int nb) {
-       double step = (to - from)/(nb-1);
-       //Log::debug() << "setRowsAxis----> from=" << from << "to=" << to << "\n";
-       
-       for ( int ind = 0; ind < nb; ind++) {
-           rowsValues_[ind] = from + (step*ind); 
-           //Log::debug() << ind << "---->" << from + (step*ind); 
-       }
-       rows_ = nb;
-     
-    }
-    
-    void setColumnsAxis(double from, double to, int nb) {
-     
-       double step = (to - from)/(nb-1);
-       //Log::debug() << "setColumnsAxis--->from=" << from << "to=" << to << "\n";
-       
-       for ( int ind = 0; ind < nb; ind++) {
-           columnsValues_[ind] = from + (step*ind);  
-            //Log::debug() << ind << "---->" << from + (step*ind); 
-       }
-       columns_ = nb;
-    }
-   
-    inline double  operator()(int i, int j) const 
-    	{ return this->matrix_.interpolate(row(i), column(j)); }  
-    
-    void matrix(magvector<double>& matrix, int& x, int& y) const
-    {
-        matrix.reserve(rows_*columns_);
-        x = columns();
-        y = rows();
-        for (int i = 0; i < x ; i++) {
-              for (int j = 0; j < y; j++) {
-                if ( i < 3 && j < 3) 
-                    //Log::debug() << "MATRIX[" << i << ", " << j << "] = " << (*this)(i,j) << "\n";
-                matrix.push_back((*this)(i,j));
-            }
-        }
-    }
 
-	void print() const
-	{
-		//Log::debug() << "RegulatorInterpolator--->" << "\n";
-		this->printAxis();
-		//Log::debug() << "--------------------->" << "\n";
-          
-		//for (int j = 0; j < rows_ ; j++) {
-		//	for (int i = 0; i < columns_; i++) {
-				//Log::debug() << (*this)(j,i) << " ";
-			//}
-			//Log::debug() <<  "\n";
-		//}
-		//Log::debug() << "<-------------------" << "\n";
-	}
-   
-     double row(int i) const {
-        map<int, double>::const_iterator x = rowsValues_.find(i);
-        if ( x != rowsValues_.end() ) return (*x).second;
-        return -1;
-    }
-    double column(int j) const {
-        map<int, double>::const_iterator y = columnsValues_.find(j);
-        if ( y != columnsValues_.end() ) return (*y).second;
-       return -1;
-    }   
-    int  rows() const { return rows_; }
-    int  columns() const { return columns_; }
-    
-protected : 
-    int rows_;
-    int columns_;
-    map<int, double> rowsValues_;
-    map<int, double> columnsValues_;
-    
-    
-   
-};
    
 
-template <class P>
-class FrameExtrapolator : public MatrixHandler<P>
-{
-public :
-    FrameExtrapolator(const AbstractMatrix& matrix) : 
-    	MatrixHandler<P>(matrix),
-    		rows_(matrix.rows()),
-        	columns_(matrix.columns()) {}
-    double left(int  i, int  j) const 
-        { 
-        
-            return  (*this)(i, j+3) - ( 3*(*this)(i, j+2)) + (3*(*this)(i, j+1)); 
-            
-        }
-    double right(int  i, int  j) const 
-        { 
-            return (*this)(i, j-3) - ( 3*(*this)(i, j-2)) + (3*(*this)(i, j-1)); 
-             
-        }
-    double top(int  i, int  j) const 
-        { 
-            return (*this)(i+3, j) - ( 3*(*this)(i+2, j)) + (3*(*this)(i+1, j)); 
-           
-        }
-    double bottom(int  i, int  j) const 
-        { 
-             return (*this)(i-3, j) - ( 3*(*this)(i-2, j)) + (3*(*this)(i-1, j)); 
-           
-        }
-      
-    double  operator()(int  i, int  j) const
-    {        
-         
-          if ( i >= 0 && i < rows_ && j >= 0 && j < columns_ ) return this->matrix_(i, j);
-          if ( i >= -2 && i < 0 )   return top(i, j);
-          if ( i >= rows_ && i < rows_ + 2 ) return bottom(i,j);
-          if ( j >= -2 && j < 0 ) return left(i, j);
-          if ( j >= columns_ && j < columns_ + 2 )  return  right(i,j);
-          return 0;
-         
-     }
 
-     void print() 
-     {
-         Log::debug() << "FrameExtrapolator--->" << "\n";
-          for (int j = -2; j < this->matrix_.rows() + 2; j++) {
-            for (int i = -2; i < this->matrix_.columns() + 2; i++) {
-                Log::debug() << (*this)(j,i) << " ";
-            }
-            Log::debug() <<  "\n";
-        }
-         Log::debug() << "<-------------------" << "\n";
-     }
-     int rows_;
-     int columns_;
-};
 
-template <class P>
-class WrapAroundMatrixHandler: public MatrixHandler<P>
-{
-public:
-     WrapAroundMatrixHandler(const AbstractMatrix& matrix) : 
-        MatrixHandler<P>(matrix) { 
-        wrapAround_ = ( matrix.width() - 1 ) >= 360;
-     
-	}
-    
-    virtual ~WrapAroundMatrixHandler() {}
-       
-    double  operator()(int  i, int  j) const
-    {
-        if ( wrapAround_ && j == this->matrix_.columns()) return this->matrix_(i, 0);
-        return this->matrix_(i, j);
-    }  
-    
-    
-    
-    int  rows() const { return this->matrix_.rows(); } 
-    int  columns() const { return wrapAround_ ? this->matrix_.columns() + 1 : this->matrix_.columns(); } 
-    double  column(int i) const { 
-        if (wrapAround_ && i == this->matrix_.columns() ) 
-            return this->matrix_.column(0) + 360;
-        return this->matrix_.column(i);
-    }
- 
-protected :
-    bool wrapAround_;
-};
-    
 
-template <class P> 
-class LongitudeBoxMatrixHandler : public MatrixHandler<P>
-{
-public:
-     LongitudeBoxMatrixHandler(const AbstractMatrix& matrix, double min = -180., double max = 180.) : 
-        MatrixHandler<P>(matrix), min_(min), max_(max) { 
-        // Check XAxis..      
-        map<double, int> sort;
-        double lon;
-        for (int i = 0; i < this->matrix_.columns(); i++) {
-            lon = this->matrix_.column(i);
-            if ( min_ <= lon && lon <= max_) sort[lon] = i;
-	    double ml = lon - 360;
-	    while ( ml >= min_ ) {  sort[ml] = i; ml -= 360; }
-	    ml = lon + 360;
-	    while ( ml <= max_ ) {  sort[ml] = i; ml += 360; }
-        }   
-     
-        int i = 0;
-        
-        for (map<double, int>::const_iterator entry = sort.begin(); entry != sort.end(); ++entry) { 
-            columns_[i++] = (*entry).second;
-            columnsValues_.push_back((*entry).first);
-        }
-    }
-    
-    virtual ~LongitudeBoxMatrixHandler() {}
-     
-    double  operator()(int  i, int  j) const
-    {
-        int x = columns_[j];
-        return this->matrix_(i, x);
-    }  
-    
-    int  rows() const { return this->matrix_.rows(); } 
-    int  columns() const { return columns_.size(); } 
-    inline double  column(int i) const { return columnsValues_[i]; }
-    
-    inline double row(int j) const { return this->matrix_.row(j); }
-    inline double interpolate(double  i, double  j) const { return this->matrix_.interpolate(i, j); }
-    double missing() const { return this->matrix_.missing(); }
-    
-protected :
-    mutable map<int, int> columns_;
-    vector<double> columnsValues_;
-    double min_;
-    double max_;
-};
+
+
 
 
 
@@ -727,8 +509,16 @@ public:
    		}
         
         
+        if ( this->mincolumn_ > this->maxcolumn_ ) {
+        	this->mincolumn_ = this->maxcolumn_;
+        	Log::warning() << "No data to plot in the requested area" << endl;
+        } 
+        if ( this->minrow_ > this->maxrow_ ) {
+        	this->minrow_ = this->maxrow_;
+        	Log::warning() << "No data to plot in the requested area" << endl;
+        }
+        //Log::broadcast();
         
-       
         this->mincolumn_ = std::max(this->mincolumn_-1, 0);
         this->maxcolumn_ = std::min(this->maxcolumn_+1, columns-1);  
         
@@ -890,18 +680,7 @@ public:
         	    	   
         	    	
         
-        
-        /* print for debug!
-        for ( int r = 0; r < this->rows(); r++) {
-        	Log::dev()<< "regular_row" << regular_latitudes_[r] << endl;
-        }
-        
-       	   
-        for ( int r = 0; r < this->rows(); r++) 
-        	
-        	for ( int c = 0; c < this->columns(); c++)
-        		Log::dev()<< "[" << r<< ", " << c << "]=[" << this->row(r, c) << ", " << this->column(r, c) << "]===>" << (*this)(r, c) <<  " (" << r  << ", " << c << ")" << endl;
-       	*/
+     
         columns_ = regular_longitudes_.size();
         
     }
@@ -1070,32 +849,6 @@ public:
     map<double, int>   newColumnsMap_;
 };
  
-template <class P>
-class SubMatrixHandler : public MatrixHandler<P>
-{
-public:
-	SubMatrixHandler(AbstractMatrix& matrix, int  i, int  j, int  x, int  y) : 
-		MatrixHandler<P>(matrix), row_(i), column_(j), rows_(x), columns_(y) {}
-
-	inline double  operator()(int  i, int  j) const 
-		{ return this->matrix_( row_ + i, column_ + j); }
-
-	void print() 
-	{
-		Log::debug() << "SubMatrix--->" << "\n";
-		for (int j = 0; j < rows_ ; j++) {
-			for (int i = 0; i < columns_; i++) Log::debug()<<(*this)(j,i)<<" ";
-			Log::debug() <<  "\n";
-		}
-		Log::debug() << "<-------------------" << "\n";
-	}
-
-protected :
-	int  row_;
-	int  column_;
-	int  rows_;
-	int  columns_;
-};
 
 template <class P>
 class OriginalMatrixHandler : public MatrixHandler<P>
