@@ -52,11 +52,25 @@ PolarStereographicProjection::~PolarStereographicProjection()
 
 void PolarStereographicProjection::print(ostream& out) const
 {
-    out << "PolarStereographicProjection[";
-    PolarStereographicProjectionAttributes::print(out);
-    out << "]"; 
+	out << "PolarStereographicProjection[";
+	PolarStereographicProjectionAttributes::print(out);
+	out << "]"; 
 } 
 
+double PolarStereographicProjection::unitToCm(double width, double height) const
+{
+	// Reproject 2 point and find the unit
+	int hemis = (hemisphere_ ==  NORTH) ? 1 : -1;
+
+	GeoPoint ll1(0,  hemis*50);
+	GeoPoint ll2(0,  hemis*51);
+	PaperPoint xy1 = (*this)(ll1);
+	PaperPoint xy2 = (*this)(ll2);
+	
+	double unit = abs(xy1.y() - xy2.y());
+	
+	return unit*(height/(getMaxY() -getMinY()) ); 
+}
 
 
 PaperPoint PolarStereographicProjection::operator()(const UserPoint& point)  const
@@ -69,10 +83,9 @@ PaperPoint PolarStereographicProjection::operator()(const GeoPoint& point)  cons
 {
 	assert(projection_);
 	TeCoord2D geo = TeCoord2D(point.longitude()*TeCDR, point.latitude()*TeCDR);
-    TeCoord2D xy = projection_->LL2PC(geo);
+	TeCoord2D xy = projection_->LL2PC(geo);
 
-     return PaperPoint(xy.x(), xy.y(), point.value(), point.missing(), point.border());
-	
+	return PaperPoint(xy.x(), xy.y(), point.value(), point.missing(), point.border());
 }
 
 PaperPoint PolarStereographicProjection::operator()(const PaperPoint& point)  const
@@ -84,9 +97,9 @@ void PolarStereographicProjection::revert(const PaperPoint& xy, GeoPoint& point)
 {
 	assert(projection_);
 	TeCoord2D texy = TeCoord2D(xy.x(), xy.y());
-    TeCoord2D geo = projection_->PC2LL(texy);
+	TeCoord2D geo = projection_->PC2LL(texy);
   
-    point = GeoPoint(geo.x()*TeCRD, geo.y()*TeCRD);
+	point = GeoPoint(geo.x()*TeCRD, geo.y()*TeCRD);
 }
 
 void PolarStereographicProjection::revert(const PaperPoint& xy, UserPoint& point)  const
@@ -100,65 +113,120 @@ bool PolarStereographicProjection::needShiftedCoastlines()  const
 	return false;
 }
 
-void PolarStereographicProjection::init(double width, double height){
-
-
+void PolarStereographicProjection::init(double width, double height)
+{
 	if ( !projection_ ) 
-				projection_ = new TePolarStereographic(TeDatum(), vertical_longitude_*TeCDR, 0., 0., "Meters", (hemisphere_ == NORTH) ? TeNORTH_HEM : TeSOUTH_HEM);
-
+		projection_ = new TePolarStereographic(TeDatum(), vertical_longitude_*TeCDR, 0., 0., "Meters", (hemisphere_ == NORTH) ? TeNORTH_HEM : TeSOUTH_HEM);
 	
 	magCompare(area_, "corners" ) ?  corners() : centre(width, height);
-	
-	TeCoord2D ll = TeCoord2D(xmin_*TeCDR, ymin_*TeCDR);
-    TeCoord2D ur = TeCoord2D(xmax_*TeCDR, ymax_*TeCDR);
+	double llx, urx , lly , ury;
+		
+	if ( magCompare(system_, "projection") == false )
+	{
+		TeCoord2D ll = TeCoord2D(xmin_*TeCDR, ymin_*TeCDR);
+		TeCoord2D ur = TeCoord2D(xmax_*TeCDR, ymax_*TeCDR);
 
-    TeCoord2D llxy = projection_->LL2PC(ll);
-    TeCoord2D urxy = projection_->LL2PC(ur);
+		TeCoord2D llxy = projection_->LL2PC(ll);
+		TeCoord2D urxy = projection_->LL2PC(ur);
     
-    TeCoord2D ell = TeCoord2D(-20*TeCDR, 40*TeCDR);
-    TeCoord2D exy = projection_->LL2PC(ell);
+		TeCoord2D ell = TeCoord2D(-20*TeCDR, 40*TeCDR);
+		TeCoord2D exy = projection_->LL2PC(ell);
     
-    ell = projection_->PC2LL(exy);
+		ell = projection_->PC2LL(exy);
     
-    // Create a grid 100/100 to calculate the corners ...
-    xmin_ = int_MAX;
-    ymin_ = int_MAX;
-    xmax_ = int_MIN;
-    ymax_ = int_MIN;
-    
-    double llx = ::min(urxy.x(), llxy.x());
-    double urx = ::max(urxy.x(), llxy.x());
-    
-    double lly = ::min(urxy.y(), llxy.y());
-    double ury = ::max(urxy.y(), llxy.y());
-    
-    double stepx= (urx - llx)/100;
-    double stepy= (ury - lly)/100;
-    for (double x = llx; x <= urx; x += stepx ) {
-        for (double y = lly; y <= ury; y += stepy ) {
-               TeCoord2D xy(x, y);
-               TeCoord2D ll = projection_->PC2LL(xy);
-               double xx = ll.x()*TeCRD;
-               double yy = ll.y()*TeCRD;
-            
-               if (xx < xmin_) xmin_ = xx;
-               if (xx > xmax_) xmax_ = xx;
-               if (yy < ymin_) ymin_ = yy;
-               if (yy > ymax_) ymax_ = yy;
-        }
+		// Create a grid 100/100 to calculate the corners ...
      
-    }
-    
-    if (xmax_ - xmin_ > 358) {
-    	// Wrap around!
-    	xmax_=180;
-    	xmin_=-180; 
-    }
+		llx = ::min(urxy.x(), llxy.x());
+		urx = ::max(urxy.x(), llxy.x());
+
+		if (llx == urx)
+		urx = llx+1000;
+
+		lly = ::min(urxy.y(), llxy.y());
+		ury = ::max(urxy.y(), llxy.y());
+
+		if (lly == ury)
+		ury = lly+1000;
+		xmin_ = int_MAX;
+		ymin_ = int_MAX;
+		xmax_ = int_MIN;
+		ymax_ = int_MIN;
+
+		double stepx= (urx - llx)/100;
+		double stepy= (ury - lly)/100;
+		for (double x = llx; x <= urx; x += stepx )
+		{
+		   for (double y = lly; y <= ury; y += stepy )
+		   {
+		       TeCoord2D xy(x, y);
+		       TeCoord2D ll = projection_->PC2LL(xy);
+		       double xx = ll.x()*TeCRD;
+		       double yy = ll.y()*TeCRD;
+
+		       if (xx < xmin_) xmin_ = xx;
+		       if (xx > xmax_) xmax_ = xx;
+		       if (yy < ymin_) ymin_ = yy;
+		       if (yy > ymax_) ymax_ = yy;
+		   }
+		}
+
+		if (xmax_ - xmin_ > 358)
+		{
+			// Wrap around!
+			xmax_=180;
+			xmin_=-180; 
+		}
 	
-	xpcmin_ = llx;
-	ypcmin_ = lly;
-	xpcmax_ = urx;
-	ypcmax_ = ury; 
+		xpcmin_ = llx;
+		ypcmin_ = lly;
+		xpcmax_ = urx;
+		ypcmax_ = ury; 
+	}
+	else {
+		llx = ::min(xmin_, xmax_);
+		urx = ::max(xmin_, xmax_);
+		lly = ::min(ymin_, ymax_);
+		ury = ::max(ymin_, ymax_);
+		TeCoord2D llxy(llx, lly);
+		TeCoord2D ll = projection_->PC2LL(llxy); 
+		TeCoord2D urxy(urx, ury);
+		TeCoord2D  ur = projection_->PC2LL(urxy); 
+		         
+		xmin_ =  ::min(ll.x()*TeCRD, ur.x()*TeCRD);
+		xmax_ = ::max(ll.x()*TeCRD, ur.x()*TeCRD); 
+		ymin_ =  ::min(ll.y()*TeCRD, ur.y()*TeCRD);
+		ymax_ =  ::max(ll.y()*TeCRD, ur.y()*TeCRD);
+		double stepx= (urx - llx)/100;
+		double stepy= (ury - lly)/100;
+		for (double x = llx; x <= urx; x += stepx )
+		{
+		   for (double y = lly; y <= ury; y += stepy )
+		   {
+        		  TeCoord2D xy(x, y);
+        		  TeCoord2D ll = projection_->PC2LL(xy);
+        		  double xx = ll.x()*TeCRD;
+        		  double yy = ll.y()*TeCRD;
+
+        		  if (xx < xmin_) xmin_ = xx;
+        		  if (xx > xmax_) xmax_ = xx;
+        		  if (yy < ymin_) ymin_ = yy;
+        		  if (yy > ymax_) ymax_ = yy;
+		   }
+		}
+
+		if (xmax_ - xmin_ > 358)
+		{
+			// Wrap around!
+			xmax_=180;
+			xmin_=-180; 
+		}
+
+		xpcmin_ = llx;
+		ypcmin_ = lly;
+		xpcmax_ = urx;
+		ypcmax_ = ury; 
+		Log::dev() << " Projection definition-->[" << ymin_ << ", " << xmin_ << ", " << xmax_ << ", " << ymax_ << "]" << endl;
+	}
 }
 void PolarStereographicProjection::fill(double& width, double& height)  
 {  
@@ -172,10 +240,7 @@ void PolarStereographicProjection::fill(double& width, double& height)
 void PolarStereographicProjection::aspectRatio(double& width, double& height)  
 {  
 	init(width, height);
-    Transformation::aspectRatio(width, height);
-    
-    
-
+	Transformation::aspectRatio(width, height);
 }
 
 void PolarStereographicProjection::boundingBox(double& xmin, double& ymin, double& xmax, double& ymax)  const
@@ -184,7 +249,6 @@ void PolarStereographicProjection::boundingBox(double& xmin, double& ymin, doubl
 	ymin=-90;
 	xmax=180;
 	ymax=90;
-	
 }
 
 double PolarStereographicProjection::getMinX()  const
@@ -254,17 +318,16 @@ double PolarStereographicProjection::getMaxPCY()  const
 void PolarStereographicProjection::gridLongitudes(const GridPlotting& grid)  const
 {
 	const vector<double>& longitudes = grid.longitudes();
-    const vector<double>& latitudes = grid.latitudes();
-    for (vector<double>::const_iterator lon = longitudes.begin(); lon != longitudes.end(); ++lon) {
+	const vector<double>& latitudes = grid.latitudes();
+	for (vector<double>::const_iterator lon = longitudes.begin(); lon != longitudes.end(); ++lon)
+	{
 		Polyline poly;
-		
-		
+
 		double min = ::min(latitudes.front(), latitudes.back());
 		double max = 80;
 		
 		for (double lat = min; lat <= max; lat += 1) { 
 			poly.push_back((*this)(GeoPoint(*lon,lat)));
-			
 		}  
 		grid.add(poly);     
 	}
@@ -273,19 +336,15 @@ void PolarStereographicProjection::gridLongitudes(const GridPlotting& grid)  con
 void PolarStereographicProjection::gridLatitudes(const GridPlotting& grid)  const
 {
 	const vector<double>& latitudes = grid.latitudes();
-    for (vector<double>::const_iterator lat = latitudes.begin(); lat != latitudes.end(); ++lat) {
-      
+	for (vector<double>::const_iterator lat = latitudes.begin(); lat != latitudes.end(); ++lat)
+	{
 	    Polyline poly;        
             for (int lon = -180; lon <= 180; lon += 1) { 
                 poly.push_back((*this)(GeoPoint(lon,*lat)));
                 
             }	
-        grid.add(poly);        
-      
-	}       
- 
-    
-    
+	    grid.add(poly);        
+	}
 }
 
 inline double CA(TeCoord2D& p1, TeCoord2D& p2)
@@ -302,6 +361,7 @@ inline double CX(double a, double b, double y)
 {
     return (y - b)/a;
 }
+
 inline double CY(double a, double b, double x)
 {
     return (a * x) + b;
@@ -405,7 +465,7 @@ void PolarStereographicProjection::labels(const LabelPlotting& label, DrawingVis
 	   	   text = new Text();
 	   	   text->setText(point.writeLatitude());
 	           text->push_back(xy);
-	           text->setBlanking(true);
+	           text->setBlanking(false);
 	   	   label.add(text);
 	    }
 	}
@@ -455,7 +515,6 @@ void  PolarStereographicProjection::visit(MetaDataVisitor& visitor, double left,
 
 	double w = getMaxPCX() - getMinPCX();
 	double h = getMaxPCY() - getMinPCY();
-	
 
 	java << "{";
 	projection_->LL2PC(java);
@@ -471,7 +530,6 @@ void  PolarStereographicProjection::visit(MetaDataVisitor& visitor, double left,
 	java << "\"pcheight\" : " << h <<  "";	
 	java << "}";	
 	visitor.add("projection", java.str());
-	
 }
 
 void PolarStereographicProjection::corners()
@@ -480,6 +538,9 @@ void PolarStereographicProjection::corners()
 	xmax_ = max_longitude_;
 	ymin_ = min_latitude_;
 	ymax_ = max_latitude_;
+		
+	if ( magCompare(system_, "projection") ) 
+		return; 
 	
 	double xmin = std::min(min_longitude_, max_longitude_);
 	double xmax = std::max(min_longitude_, max_longitude_);
@@ -538,72 +599,78 @@ void PolarStereographicProjection::centre(double width, double height)
 
 void PolarStereographicProjection::thin(MatrixHandler<GeoPoint>& matrix, double x, double y, vector<GeoPoint>& out) const
 {
-   ThinningMatrixHandler<GeoPoint> original(matrix, 1, 1);
-
-	GeoPoint ll1(0, 60.);
-	GeoPoint ll2(original.XResolution(), 60.);
+	int xfactor = (int) ceil((float) x);
+	int yfactor = (int) ceil((float) y);
+    
+	ThinningMatrixHandler<GeoPoint> original(matrix, 1, 1);
+	double lat = hemisphere_ == NORTH ? 90 : -60;
+   
+	GeoPoint ll1(0, lat);
+	GeoPoint ll2(original.XResolution(),  lat);
 	PaperPoint xy1 = (*this)(ll1);
 	PaperPoint xy2 = (*this)(ll2);
 	
-	double factor = ff(xy1, xy2)*x;
+	double factor = ff(xy1, xy2)*xfactor;
 	
 	
-	 int columns = original.columns();
-	 int rows = original.rows();
+	int columns = original.columns();
+	int rows = original.rows();
 
-	 PaperPoint last, first;
-	 double savelat = -1;
+	PaperPoint last, first;
+	double savelat = -1;
 	 
-     
-     for ( int row = 0; row < rows; row+=y) {
-     	     
-     	    double savelon = -1;
-					
-			
-			
-	        for ( int column = 0; column < columns; column++) {
-                double lat = original.row(row, column);	
-	            double lon = original.column(row, column);
-                if (hemisphere_ == NORTH && lat < -20) continue;
+	for ( int row = 0; row < rows; row+=yfactor)
+	{
+		double savelon = -1;
+
+		for ( int column = 0; column < columns; column++)
+		{
+			double lat = original.row(row, column);	
+			double lon = original.column(row, column);
+			if (hemisphere_ == NORTH && lat < -20) continue;
 			if (hemisphere_ == SOUTH && lat > 20) continue;
-			if (savelat != -1) {
+			if (savelat != -1)
+			{
 				PaperPoint previous = (*this)(GeoPoint(savelon, savelat));
 				PaperPoint current = (*this)(GeoPoint(lon, lat));
 				if ( ff(previous, current) < factor ) continue;
 				savelat = lat;
 			}			
-			    GeoPoint point(lon, lat, original(row, column));
-			 
+			GeoPoint point(lon, lat, original(row, column));
 
-				PaperPoint xy = (*this)(point); 
-				if ( column == 0 ) first = xy;
-				
-				if ( savelon == -1) {
-					savelon = lon;
-					savelat = lat;
-					last = xy;
-					if ( in(xy) )
-						out.push_back(point);
-					continue;
-				}
-				if ( ff(last, xy) > factor && ff(first, xy) > factor)  {						
-					last = xy;
-					if ( in(xy) )
-						out.push_back(point); 
-				}	
+			PaperPoint xy = (*this)(point); 
+			if ( column == 0 ) first = xy;
+
+			if ( savelon == -1)
+			{
+				savelon = lon;
+				savelat = lat;
+				last = xy;
+				if ( in(xy) )
+					out.push_back(point);
+				continue;
+			}
+			if ( ff(last, xy) > factor && ff(first, xy) > factor)
+			{						
+				last = xy;
+				if ( in(xy) )
+					out.push_back(point); 
+			}	
 		}
-	 }
+	}
 }
 
 bool PolarStereographicProjection::concatenate(vector<Polyline* >& lines, Polyline* poly) const 
 {
 	if (poly->empty()) return true;
-	for ( vector<Polyline* >::iterator  line = lines.begin(); line != lines.end(); ++line) {
+	for ( vector<Polyline* >::iterator  line = lines.begin(); line != lines.end(); ++line)
+	{
 		Polyline* building = *line;
 		// concatenate front???
 		if ( building->empty() ) continue;
 		
-		if ( (*line)->front() == poly->back() ) {
+		if ( (*line)->front() == poly->back() )
+		{
 //			Log::dev()<< "concatenate to the front" << (*line)->front() << " == " <<  poly->back() << endl;
 			(*line)->insert((*line)->begin(), poly->begin(), poly->end());
 			lines.erase(line);
@@ -611,7 +678,8 @@ bool PolarStereographicProjection::concatenate(vector<Polyline* >& lines, Polyli
 			return true;			
 		}
 		// concatenate back???
-		if ( (*line)->back() == poly->front()  ) {
+		if ( (*line)->back() == poly->front()  )
+		{
 //			Log::dev()<< "concatenate to the back" << (*line)->back() << " == " <<  poly->front() << endl;
 			(*line)->insert((*line)->end(), poly->begin(), poly->end());
 			lines.erase(line);
@@ -625,48 +693,62 @@ bool PolarStereographicProjection::concatenate(vector<Polyline* >& lines, Polyli
 }
 
 
-void	PolarStereographicProjection::setNewPCBox(double minx, double miny, double maxx, double maxy)
-	{
-		   PaperPoint p1(minx, miny);
-		   PaperPoint p2(maxx, maxy);
-		   GeoPoint   ll, ur;
-		   
-		   revert(p1, ll);
-		   revert(p2, ur);
-		   
-		   cout << ll << endl;
-		   cout << ur << endl;
-		  
-		   min_longitude_ = ll.x();
-		   max_longitude_ = ur.x();
-		   min_latitude_ = ll.y();
-		   max_latitude_ = ur.y();
-		
-		   corners();
-	}
+void PolarStereographicProjection::setNewPCBox(double minx, double miny, double maxx, double maxy)
+{
+	PaperPoint p1(minx, miny);
+	PaperPoint p2(maxx, maxy);
+	GeoPoint   ll, ur;
 
-/*
-void PolarStereographicProjection::shadingConsistent(Polyline& from) const
-{		
-	if ( !from.isClosed() ) {		
-		Polyline::iterator point = from.begin();
-		Polyline::iterator front = from.begin();
-		point++;
-		vector<Polyline::iterator >  keep;
-	
-		while (point != from.end())
-		{
-			if  (*front == *point) {			
-				++front;
-				keep.push_back(++point);
-			}
-			else ++point;
-		}    
-    	if ( !keep.empty() )
-    		from.erase(keep.front(), from.end());
-	}
-    if (from.isClosed()) 
-		rotate(from);
-  	
+	revert(p1, ll);
+	revert(p2, ur);
+
+	cout << ll << endl;
+	cout << ur << endl;
+
+	min_longitude_ = ll.x();
+	max_longitude_ = ur.x();
+	min_latitude_ = ll.y();
+	max_latitude_ = ur.y(); 
+
+	corners();
 }
-*/
+
+void PolarStereographicProjection::operator()(const GeoPoint& geo, vector<PaperPoint>& out) const
+{
+	PaperPoint pp = (*this)(geo);
+		if ( in(pp) ) 
+			out.push_back(pp);
+}
+
+void PolarStereographicProjection::reprojectComponents(const GeoPoint& point, pair<double, double>& components) const
+{
+	double s1 = sqrt((components.first * components.first) + (components.second * components.second));
+	GeoPoint u(point.x() + components.first, point.y());
+	GeoPoint v(point.x(), point.y() + components.second);
+
+	PaperPoint up = (*this)(u);
+	PaperPoint vp = (*this)(v);
+	PaperPoint p = (*this)(point);
+
+	components.first = (up.x() - p.x()) + (vp.x() - p.x());
+	components.second = (up.y() - p.y()) + (vp.y() - p.y());
+
+	double s2 = sqrt((components.first * components.first) + (components.second * components.second));
+	double f = s1/s2;
+	components.first *= f;
+	components.second *= f;	
+}
+
+void PolarStereographicProjection::reprojectSpeedDirection(const PaperPoint& point, pair<double, double>& wind) const
+{
+  	double a = 90 - (wind.second); 
+  	double speed =wind.first; 
+  	double x = 3.14/180.;
+	a *= x;
+    GeoPoint geo;
+    wind.first = speed-1 * cos(a);
+    wind.second = speed-1 * sin(a);
+    reprojectComponents(geo, wind);
+}
+
+
