@@ -53,11 +53,7 @@ GribDecoder::GribDecoder() :  matrix_(0),  xComponent_(0), yComponent_(0), handl
 	title_ = "grib_" + tostring(count_);
 	version();
 }
-string GribDecoder::name() 
-{
-	decode();
-	return name_;
-}
+
 void GribDecoder::version()
 {
 	static bool done = false;
@@ -130,11 +126,11 @@ void   GribDecoder::setDouble(const string& key, double val) const
 		Log::info() << "Grib Api : can not find key [" << key << "]\n";
 		Log::info() << grib_get_error_message(err) <<"\n";
 	}
-	
+
 }
 
 
-void GribDecoder::read(int position, Matrix **matrix)
+void GribDecoder::read(Matrix **matrix)
 {
 	
 	long repres;    
@@ -180,19 +176,29 @@ void GribDecoder::decode2D()
 	Matrix     *w1 = 0;
     Matrix     *w2 = 0;     
     
-    grib_field_position_ =  position_1_;
-    open();
-    read(position_1_, &w1);
+   
+    openFirstComponent();
+    read(&w1);
     
-    grib_field_position_ =  position_2_;
-    open();
-    read(position_2_, &w2);
     
-    wind_mode_->x(&xComponent_, w1, w2);
-    wind_mode_->y(&yComponent_, w1, w2);
+    openSecondComponent();
+    read(&w2);
+    
+    wind_mode_->x(&xComponent_, &yComponent_, w1, w2);
     
 }
 
+void GribDecoder::openFirstComponent() 
+{
+	  grib_field_position_ =  position_1_;
+	  open();
+}
+
+void GribDecoder::openSecondComponent() 
+{
+	  grib_field_position_ =  position_2_;
+	  open();
+}
 
 
 void  GribDecoder::open() 
@@ -263,7 +269,25 @@ Data<GeoPoint>* GribLoop::current()
 	return grib_;
 }
 
+map<string, string> GribLoop::ids_;
+int GribLoop::index_ = 0;
+
 void        GribLoop::next() {}
+	
+GribLoop::GribLoop::GribLoop():  grib_(0), file_(0)
+{
+		current_ = dim_.begin();
+		current1_ = dim_1_.begin();
+		current2_ = dim_2_.begin();
+}
+
+void GribLoop::setToFirst() 
+{
+	current_ = dim_.begin();
+	current1_ = dim_1_.begin();
+	current2_ = dim_2_.begin();
+}
+
 bool  GribLoop::hasMore()
 {
 	if (file_ == 0 ) {
@@ -275,12 +299,78 @@ bool  GribLoop::hasMore()
 	}
 	
     grib_context* context = GribDecoder::gribContext();
-    int error;
-    grib_handle* handle = grib_handle_new_from_file(context, file_, &error) ; 
-    if (handle <=0) 
-	    return false;
-    grib_ = new GribEntryDecoder(handle);
-    grib_->icon(*this);
+    
+    // Now we have to find the right Entry!!! 
+    
+    //check the dimension 
+    
+    if ( dimension_ < 1 || dimension_ > 2 ) {
+    	Log::warning() << " GribLoop setting grib_dimension reset to 1" << endl;
+    }
+    
+   
+    if ( dimension_ == 1 ) {   
+    	if (  dim_.empty() ) {
+    		 // case 1 dimension= 1 and loop on all the fields! 
+    		int error;
+    		grib_handle* handle = grib_handle_new_from_file(context, file_, &error) ; 
+    		if (handle <=0)  return false;
+    		grib_ = new GribEntryDecoder(handle);
+    	}
+    	else {
+    		if ( current_ == dim_.end() )
+    			return false;
+    		 // Case 3 Dimension = 1 but we only used  a subset of fields
+    		grib_handle* handle =  (*address_mode_)(context, file_, *current_);
+    		current_++;
+    		if (handle <=0)  
+    			return false;
+    		grib_ = new GribEntryDecoder(handle);
+    	
+    	}
+    }
+    
+   
+    if ( dimension_ == 2) {
+    	if ( dim_1_.empty()  ) {
+    	 // case 2 Dimension = 2 and loop on all the field!
+    		int error;
+       		grib_handle* handle1 = grib_handle_new_from_file(context, file_, &error) ; 
+       		if (handle1 <=0)  return false;	
+       		grib_handle* handle2 = grib_handle_new_from_file(context, file_, &error) ; 
+           	if (handle2 <=0)  return false;
+           	grib_ = new GribEntryDecoder(handle1, handle2);
+    	}
+        else {
+        	// Case 4 Dimesnion = 2 and we only used a subset of fields! 
+        	if ( current1_ ==  dim_1_.end() || current2_ ==  dim_2_.end() )
+        		return false;
+        	
+        	grib_handle* handle1 =  (*address_mode_)(context, file_, *current1_);
+        	grib_handle* handle2 =  (*address_mode_)(context, file_, *current2_);
+        	if ( handle1 <=0 )  
+        		return false;
+        	if ( handle2 <=0 )  
+        	       return false;
+        	grib_ = new GribEntryDecoder(handle1, handle2);
+        	current1_++;
+        	current2_++;
+        }
+   }
+
+     
+    grib_->setFile_name(path_);
+    if ( iconName_.empty() ) {
+    		map<string, string>::iterator id = ids_.find(path_);
+    		if ( id == ids_.end() ) {
+    		    		iconName_ = "Grib" + tostring(index_);
+    		    		index_++;
+    		    		ids_.insert(make_pair(path_, iconName_));  		
+    		 }
+    		  else 
+    		    		iconName_ = id->second;
+    }
+   grib_->icon(*this);
 	return true;
 }
 
@@ -331,6 +421,36 @@ public:
 			long step =  grib_.getLong("startStepInHours");
 			
 						
+			Date part1 = Date(day);
+			magics::Time part2 = magics::Time(hour, mn, 0);
+			DateTime full(part1, part2);	
+			 full = full + (step*3600);
+			tm convert = full;
+			try {
+				locale loc("");
+				ostringstream out;
+				out.imbue(loc);   
+				const std::time_put<char>& tfac = use_facet<time_put<char> >(loc); 
+				tfac.put(out, out, ' ', &convert, format.c_str(), format.c_str()+format.length());       
+				return out.str();
+			}
+			catch (...)
+				{
+					Log::error() << "Problem to setup the locale" << endl;
+					Log::error() << "Check you LOCALE variable-->current value : " <<  getEnvVariable("LANG")<< endl;
+					assert(false);
+				}
+		}
+	string validDate(const XmlNode& node) {
+			string format= node.getAttribute("format");
+			if ( format.empty() )  
+				format =  "%A %d %B %Y at %H UTC";
+			long day =  grib_.getLong("date");  
+			long hour = grib_.getLong("hour");  
+			long mn =  grib_.getLong("minute");
+			long step =  grib_.getLong("stepRange");
+			
+						
 			Date part1 = Date(day);
 			magics::Time part2 = magics::Time(hour, mn, 0);
 			DateTime full(part1, part2);	
@@ -398,6 +518,10 @@ public:
 				title_.update("grib"+grib, def, baseDate(node));
 				return;
 			}
+			if ( def == "valid-date" ) {
+				title_.update("grib"+grib, def, validDate(node));
+				return;
+			}
 			if ( def == "start-date" ) {
 							title_.update("grib"+grib, def, startDate(node));
 							return;
@@ -473,7 +597,7 @@ void GribDecoder::visit(AnimationStep& step) {
 	   		from_ = DateTime(helper.get("grib", "start-date"));
 	   		to_ =  DateTime(helper.get("grib", "end-date"));
 	   		
-		   MatrixHandler<GeoPoint>& data = matrix() ; 
+		   //MatrixHandler<GeoPoint>& data = matrix() ; 
 		   // Information about contains...
 		   	Log::dev() << "GribDecoder::visit(AnimationRules&) --> " << endl;
 		   	
@@ -487,8 +611,8 @@ void GribDecoder::visit(AnimationStep& step) {
 		   		}
 		   		
 		       // information about resolution...
-		   	step.xResolution(abs(data.XResolution()));
-		   	step.yResolution(abs(data.YResolution()));
+		   		step.xResolution(1.5); //step.xResolution(abs(data.XResolution()));
+		   		step.yResolution(1.5); //	step.yResolution(abs(data.YResolution()));
 	         }
 	   catch (...)
 	   {
@@ -505,7 +629,10 @@ void GribDecoder::decode()
 	if (matrix_) return;
 	
 	open();
-	read(grib_field_position_, &matrix_);
+	
+	read(&matrix_);
+	
+	// here we build information for the layers!
 	TagHandler helper; 
 	vector<string> need;
 	need.push_back("<grib_info id=\'" + id_ +"\' key='shortName'/>");
@@ -517,7 +644,10 @@ void GribDecoder::decode()
 		   		for ( vector<string>::const_iterator t = need.begin(); t != need.end(); ++t ) {
 		   			tag1.decode(*t);
 		   		}
+		   		
 		   		name_ = helper.get("grib"+id_, "shortName") +  "-" +  helper.get("grib"+id_, "lev");
+		   		name_ = iconName_;
+		   		layerId_ = name_ + file_name_;
 		   		from_ = DateTime(helper.get("grib"+id_, "start-date"));
 		   		to_ =  DateTime(helper.get("grib"+id_, "end-date"));
 		   		
@@ -573,18 +703,17 @@ void GribDecoder::visit(TextVisitor& title)
 void GribDecoder::decodeRaster() 
 {
 	open();
-	double representation = getDouble("dataRepresentationType");
-	string repres = getString("typeOfGrid");
-	ostringstream os;
-	os << representation;     
+	
+	string representation = getString("typeOfGrid");
+	
 	try {
-		GribInterpretor* interpretor = SimpleObjectMaker<GribInterpretor>::create(os.str());
+		GribInterpretor* interpretor = SimpleObjectMaker<GribInterpretor>::create(representation);
 		interpretor->interpretAsRaster(*this, raster_);
 	}
     
     catch (NoFactoryException&)
     {
-    	Log::error() << "Grib Decoder: Representation [" << os << "] not yet supported.\n";
+    	Log::error() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n";
     	throw MagicsException("Grib Decoder: Representation [] not yet supported.");
     }
 }
