@@ -52,8 +52,6 @@ void GribInterpretor::scaling(const GribDecoder& grib, Matrix** matrix) const
 
 	long derived = grib.getLong("generatingProcessIdentifier");
 	
-	if (derived == 254) 
-		  return;
 	
 	
 	
@@ -65,6 +63,7 @@ void GribInterpretor::scaling(const GribDecoder& grib, Matrix** matrix) const
 	
 	if (grib.getScaling())
 	{
+		if (derived != 254)  {
 		try {
 			const ParamDef& paramdef = LocalTable::localInfo(param, table, centre);
 			(*matrix)->multiply(paramdef.scaling());
@@ -74,7 +73,13 @@ void GribInterpretor::scaling(const GribDecoder& grib, Matrix** matrix) const
 		{
 			Log::warning() << " Can not find information for the parameter [" << param << "." << table << "]\n";
 		}
+		}
 	}
+	else {
+		(*matrix)->multiply(grib.getScaling_factor());
+		(*matrix)->plus(grib.getScaling_offset());
+	}
+
 }
 
 /*!
@@ -116,9 +121,13 @@ void GribRegularInterpretor::interpretAsMatrix(const GribDecoder& grib, Matrix**
   
 
   Log::dev() << "NewAPI---> area[" << west << ", " << north << ", " << east << ", " << south << "]" << "\n";
-  double lon = longitudeIncrement(grib);
+  double loni = longitudeIncrement(grib);
   
+  double lon = (east-west)/(nblon-1);
   
+  Log::dev() << "increment -->" << loni << " (from->" << west << " to-->" << west + (nblon-1) *loni << ")" <<  endl;
+  Log::dev() << "calcul -->" << lon << " (from->" << west << " to-->" << west + (nblon-1) *lon << ")" <<  endl;
+
   latitudes(grib, (*matrix)->rowsAxis());
   
   
@@ -131,7 +140,8 @@ void GribRegularInterpretor::interpretAsMatrix(const GribDecoder& grib, Matrix**
 	{
 	    
 		(*matrix)->columnsAxis().push_back(x);
-		x  += lon;
+		x  = west + (i+1)*lon;
+		
 	}
 	
  
@@ -139,18 +149,16 @@ void GribRegularInterpretor::interpretAsMatrix(const GribDecoder& grib, Matrix**
   (*matrix)->setMapsAxis();
 
   
-  double *data = new double[nb];
-  
-  size_t aux = size_t(nb);
-  grib_get_double_array(grib.id(),"values",data,&aux); 
-  (*matrix)->missing(missing);
-  for (unsigned int i = 0; i < nb; i++)
-  {
-        (*matrix)->push_back(data[i]);
-  }
-
-  delete [] data;
-  
+ try { 
+	 (*matrix)->resize(nb);
+  	size_t aux = size_t(nb);
+  	grib_get_double_array(grib.id(),"values", &(*matrix)->front(),&aux); 
+  	(*matrix)->missing(missing);
+ } 
+ catch (...) 
+ {
+	 throw MagicsException("Not enough memory");
+ }
   
 }
 
@@ -203,49 +211,64 @@ double GribRegularInterpretor::longitudeIncrement(const GribDecoder& grib) const
 
 
 
-void GribRegularInterpretor::interpretAsRaster(const GribDecoder& , RasterData<GeoPoint>& ) const
-//void GribRegularInterpretor::interpretAsRaster(const GribDecoder& grib, RasterData<GeoPoint>& raster) const
+
+void GribRegularInterpretor::interpretAsRaster(const GribDecoder& grib, RasterData<GeoPoint>& raster) const
 {
-//	Log::dev() << "GribRegularInterpretor::interpretAsRaster" << "\n";
+	Log::dev() << "GribRegularInterpretor::interpretAsRaster" << "\n";
+	
+	
+	
+	 double north = grib.getDouble("latitudeOfFirstGridPointInDegrees");
+	  double west = grib.getDouble("longitudeOfFirstGridPointInDegrees");
+	  double south = grib.getDouble("latitudeOfLastGridPointInDegrees");; 
+	  double east = grib.getDouble("longitudeOfLastGridPointInDegrees");;
+	Log::dev() << "area[" << north << ", " << west << ", " << south << ", " << east << "]" << "\n";
+	
+	raster.setUpperRightCorner(north, east);
+	raster.setLowerLeftCorner(south, west);
+
+	
+	double lon = longitudeIncrement(grib);
+	int scanning = grib.getLong("jScansPositively") ? 1 : -1;
+	double lat =  scanning * grib.getDouble("jDirectionIncrementInDegrees");
+	
+	
+	
+	raster.setXResolution(lon);
+	raster.setYResolution(lat);
+	
+	 long nblon = grib.getLong("numberOfPointsAlongAParallel");
+	  long nblat = grib.getLong("numberOfPointsAlongAMeridian");
+	
+	raster.setColumns(nblon);
+	raster.setRows(nblat);
 //	
-//	double north, west, south, east;
-//	grib_get(grib.id(), (grib_string_t*)"area", "r", &north, &west, &south, &east);
-//	Log::dev() << "area[" << north << ", " << west << ", " << south << ", " << east << "]" << "\n";
-//	
-//	raster.setUpperRightCorner(north, east);
-//	raster.setLowerLeftCorner(south, west);
-//	
-//	
-//	double lon, lat;	
-//	grib_get(grib.id(), (grib_string_t*)"gridIncrements", "R", &lon, &lat);
-//	Log::dev() << "GridIncrements[" << lon << ", " << lat << "]" << "\n";
-//	
-//	raster.setXResolution(lon);
-//	raster.setYResolution(lat);
-//	
-//	grib_int_t nblon, nblat;	
-//	grib_get(grib.id(), (grib_string_t*)"gridDimensions", "i", &nblon, &nblat);
-//	Log::dev() << "GridDimensions[" << nblon << ", " << nblat << "]" << "\n";
-//	
-//	raster.setColumns(nblon);
-//	raster.setRows(nblat);
-//	
-//	raster.setProjection(new TeLatLong(TeDatum()));
-//	double missing = std::numeric_limits<double>::max();
-//	grib_int_t nb, nb1;
-//	grib_get( grib.id(),(grib_string_t*)"numberOfFieldValues","I",&nb);
-//	Log::dev() << "numberOfFieldValues[" << nb << "]" << "\n";
-// 
-//	grib_real_t buffer[nb];
-//    
-//	grib_getdata(grib.id(),&missing, buffer, nb, &nb,&nb1);
-//	
-// 
-//    raster.reserve(nb);
-//    	
-//    for (int i = 0; i < nb; i++)
-//        raster.push_back(buffer[i]);
-//   
+	raster.setProjection(new TeLatLong(TeDatum()));
+	double missing = std::numeric_limits<double>::max();
+	size_t nb;
+	grib_get_size(grib.id(), "values", &nb);
+ 
+	double *data = new double[nb];
+	  
+	size_t aux = size_t(nb);
+	
+	grib_get_double_array(grib.id(),"values",data,&aux); 
+	vector<double> tmp;
+	 for (int i = 0; i < nb; i++)
+	        tmp.push_back(data[i]);
+	 
+	 double min = *(std::min_element(tmp.begin(), tmp.end()));
+	 double max = *(std::max_element(tmp.begin(), tmp.end()));
+  
+	 double step = (max-min)/126;
+	 
+    raster.reserve(nb);
+    	
+    for (int i = 0; i < nb; i++) {
+    	
+      //cout << data[i] << "---> " << int ((data[i]/step) ) << endl;
+        raster.push_back(data[i]);
+    } 
 }
 
 
@@ -528,56 +551,6 @@ GeoPoint GribLambertAzimutalInterpretor::unrotate(double lat, double lon) const
 
 
 
-class ProjectedMatrix: public Matrix
-{
-public:
-		ProjectedMatrix(int rows, int columns): Matrix( rows, columns) {
-			 rows_ = rows;
-			         columns_ = columns;
-			         reserve(rows_*columns_); 
-			         rowsAxis_.reserve(rows);  
-			         rowsArray_.reserve(rows_*columns_);  
-			         columnsArray_.reserve(rows_*columns_);  
-			         columnsAxis_.reserve(columns);  
-		}
-	
-		double row(int row, int column) const {
-			 return rowsArray_[ row * columns_ + column];
-		}
-		
-		double column(int row, int column) const {
-					 return columnsArray_[ row * columns_ + column];
-				}
-		  double real_column(int row, int column) const { 
-			  return columnsArray_[ row * columns_ + column];
-		      
-		  }
-		  double real_row(int row,  int column) const { 
-			  return rowsArray_[ row * columns_ + column];
-		   }
-		  vector<double>&  rowsArray() const { return rowsArray_; }
-		  vector<double>&  columnsArray() const { return columnsArray_; }
-		  void setMapsAxis() 
-		    {
-		        
-		        for (int i = 0; i < rows_; i++) {
-		            rowsAxis_.push_back(i);
-		        	rowsMap_[i] = i;
-		        }
-		        for (int i = 0; i < columns_; i++) {
-		        	columnsAxis_.push_back(i);
-		        	columnsMap_[i] = i;
-		       }
-		        
-		        
-		       
-		    }
-protected:
-		  mutable vector<double> rowsArray_;
-		  mutable vector<double> columnsArray_; 
-		 
-			
-};
 
 void GribLambertAzimutalInterpretor::interpretAsMatrix(const GribDecoder& grib, Matrix** matrix) const
 {
