@@ -53,6 +53,7 @@ protected :
 		{ p.print(s); return s; }
 };
 
+
 class BufrFamily : public map<string, BufrSubType> 
 {
 public:
@@ -60,55 +61,71 @@ public:
 	~BufrFamily() {};
 	
 	void currentType(const map<string, string>& def) { type_ = def.find("value")->second; }
-	void currentSubtype(const map<string, string>& def) { 
+
+	void currentSubtype(const map<string, string>& def)
+	{
 		map<string, string>::const_iterator value = def.find("value");
-		if ( value == def.end() ) {
+		if ( value == def.end() )
+		{
 			Log::warning() << " No code defined for subtype--> Contact graphics team.\n";
 			subtype_ = "???";
 		}
-		else subtype_ = def.find("value")->second; 
+		else 
+		  subtype_ = def.find("value")->second;
+
 		map<string, string>::const_iterator tmpl = def.find("template");
 		template_ = ( tmpl != def.end() ) ? tmpl->second : "";
 		subtypeToBeSet_ = true; 
 	}
-	void addSubtype(const string& value) { 
+
+	void addSubtype(const string& value)
+	{
 		if (template_ == "") template_ = value;
 		(*this)[type_].insert(make_pair(subtype_, template_)); 
 		subtypeToBeSet_ = false;
-		}
+	}
+
 	bool subtype() { return subtypeToBeSet_; }
+
 	void subtypeToReset() { subtypeToBeSet_ = false; }
 	
-	string getType(const string& type, const string& subtype) const {
+	string getType(const string& type, const string& subtype) const
+	{
 		const_iterator t = find(type);
-		if ( t != end() ) {
+		if ( t != end() )
+		{
 			BufrSubType::const_iterator s = t->second.find(subtype);
 			if (s != t->second.end() ) return s->second;
 		}
 		return "";
 	}
-	
+
 protected :
-	void print(ostream& out) const {
+	void print(ostream& out) const
+	{
 		for (const_iterator type = begin(); type != end(); ++type) 
 			out << type->first << "=[" << type->second << "]";
 	} 
+
 	string type_;
 	string subtype_;
 	string template_;
-	bool      subtypeToBeSet_;
+	bool   subtypeToBeSet_;
 	string centre_;
+
 	//! Overloaded << operator to call print().
 	friend ostream& operator<<(ostream& s,const BufrFamily& p)
 		{ p.print(s); return s; }
 };
 
+
 class BufrFamilyTable : public map<string, BufrFamily*>
 {
 public :
 	BufrFamilyTable() {}
 	~BufrFamilyTable() {}
-	static const BufrFamily& get(const string& centre) { 
+	static const BufrFamily& get(const string& centre)
+	{
 		const_iterator table = table_.find(centre);
 		if ( table != table_.end() ) return *(table->second);
 		BufrFamily*  idents = new BufrFamily(centre);
@@ -216,7 +233,8 @@ int BufrIdentifiers::ident(const string& token) const
 BufrIdentTable BufrIdentTable::table_;
 BufrFamilyTable BufrFamilyTable::table_;
 
-BufrFamily::BufrFamily(const string& centre) : centre_(centre) {
+BufrFamily::BufrFamily(const string& centre) : centre_(centre)
+{
 	ostringstream file;
 	file << getEnvVariable("MAGPLUS_HOME") <<  MAGPLUS_PATH_TO_SHARE_ << "bufr_" << centre << ".xml";
 	char buf[BUFSIZ];
@@ -261,7 +279,8 @@ public:
 	BufrAccessor(const string& descriptor) : descriptor_(descriptor) {}
 	virtual ~BufrAccessor() {};
 	virtual void operator()(const ObsDecoder&, MvObs&, string&) const {}
-	virtual void operator()(const ObsDecoder&, MvObs& obs, double& val) const {
+	virtual void operator()(const ObsDecoder&, MvObs& obs, double& val) const
+	{
 		const BufrIdentifiers& table =  BufrIdentTable::get(obs.originatingCentre());
 		val = obs.value(table.ident(descriptor_));
 		Log::dev()<< "BufrAccessor-Descriptor--->" << descriptor_ << " Value--->" << val << endl;
@@ -308,6 +327,46 @@ public:
 	virtual ~BufrHighCloudAccessor() {}
 };
 
+class BufrLowCloudNebulosityAccessor : public BufrMultiValueAccessor 
+{
+public:
+	BufrLowCloudNebulosityAccessor() : BufrMultiValueAccessor("low_cloud_nebulosity", 1) {}
+	virtual ~BufrLowCloudNebulosityAccessor() {}
+};
+
+class BufrMediumCloudNebulosityAccessor : public BufrMultiValueAccessor 
+{
+public:
+	BufrMediumCloudNebulosityAccessor() : BufrMultiValueAccessor("medium_cloud_nebulosity", 2) {}
+	virtual ~BufrMediumCloudNebulosityAccessor() {}
+};
+
+class BufrHighCloudNebulosityAccessor : public BufrMultiValueAccessor 
+{
+public:
+	BufrHighCloudNebulosityAccessor() : BufrMultiValueAccessor("high_cloud_nebulosity", 3) {}
+	virtual ~BufrHighCloudNebulosityAccessor() {}
+};
+class BufrLowCloudHeightAccessor : public BufrMultiValueAccessor 
+{
+public:
+	BufrLowCloudHeightAccessor() : BufrMultiValueAccessor("low_cloud_height", 1) {}
+	virtual ~BufrLowCloudHeightAccessor() {}
+};
+
+class BufrMediumCloudHeightAccessor : public BufrMultiValueAccessor 
+{
+public:
+	BufrMediumCloudHeightAccessor() : BufrMultiValueAccessor("medium_cloud_height", 2) {}
+	virtual ~BufrMediumCloudHeightAccessor() {}
+};
+
+class BufrHighCloudHeightAccessor : public BufrMultiValueAccessor 
+{
+public:
+	BufrHighCloudHeightAccessor() : BufrMultiValueAccessor("high_cloud_height", 3) {}
+	virtual ~BufrHighCloudHeightAccessor() {}
+};
 
 
 class BufrTypeAccessor : public BufrAccessor 
@@ -447,10 +506,25 @@ SimpleObjectMaker<BufrLowCloudAccessor, BufrAccessor> low_cloud_accessor("low_cl
 SimpleObjectMaker<BufrMediumCloudAccessor, BufrAccessor> medium_cloud_accessor("medium_cloud");
 SimpleObjectMaker<BufrHighCloudAccessor, BufrAccessor> high_cloud_accessor("high_cloud");
 
+SimpleObjectMaker<BufrLowCloudHeightAccessor, BufrAccessor> low_cloud_nebulosity_accessor("low_cloud_height");
+SimpleObjectMaker<BufrMediumCloudHeightAccessor, BufrAccessor> medium_cloud_nebulosity_accessor("medium_cloud_height");
+SimpleObjectMaker<BufrHighCloudHeightAccessor, BufrAccessor> high_cloud_nebulosity_accessor("high_cloud_height");
 
+SimpleObjectMaker<BufrLowCloudNebulosityAccessor, BufrAccessor> low_cloud_height_accessor("low_cloud_nebulosity");
+SimpleObjectMaker<BufrMediumCloudNebulosityAccessor, BufrAccessor> medium_cloud_height_accessor("medium_cloud_nebulosity");
+SimpleObjectMaker<BufrHighCloudNebulosityAccessor, BufrAccessor> high_cloud_heightaccessor("high_cloud_nebulosity");
+
+
+
+/*!
+ 
+\class ObsDecoder
+
+*/
 ObsDecoder::ObsDecoder()
 {
-	if ( multilevels_.empty() ) {
+	if ( multilevels_.empty() )
+	{
 		multilevels_[0] = false;
 		multilevels_[1] = false;
 		multilevels_[2] = true;
@@ -470,23 +544,23 @@ void ObsDecoder::decode()
 	MvObsSet obsSet(file_name_.c_str());
 
 	// Test 
-        MvObsSetIterator   obsIterator(obsSet);
+        MvObsSetIterator obsIterator(obsSet);
 	MvObs obs = obsIterator();
 
 	ostringstream title;
-       
 	title << "Observation: " << obs.obsTime() << " [ type = " << obs.messageType() << " , subtype = " << obs.messageSubtype() << "]";
 	title_ = title.str();
         
 	while (obs)
 	{
-		MvLocation loc = obs.location();
-
-//		Log::dev()<< obsIterator.msgNumber() << " " << loc << " " << time << " " << obs.WmoIdentNumber() << endl;
-//		Log::dev()<< "type=" << obs.messageType() << ", subtype=" << obs.messageSubtype() << "\n";
-//		Log::dev()<< "lat=" << obs.value(5001) << ", lon=" << obs.value(6001) << "\n";
-//		Log::dev()<< "tempe=" << obs.value(12004)  << "\n";
-		push_back(GeoPoint(loc.x(), loc.y(), obs.value(12004)));
+		MvLocation location = obs.location();
+#ifdef OBS_DEBUG_
+		cout << obsIterator.msgNumber() << " " << location << " " << time << " " << obs.WmoIdentNumber()
+		     << "\n\ttype=" << obs.messageType() << ", subtype=" << obs.messageSubtype()
+		     << "\n\tlat=" << obs.value(5001) << ", lon=" << obs.value(6001)
+		     << "\n\ttempe=" << obs.value(12004)  << endl;
+#endif
+		push_back(GeoPoint(location.x(), location.y(), obs.value(12004)));
 		obs = obsIterator();
 	}
 }
@@ -504,6 +578,7 @@ bool ObsDecoder::findInTypes(const string& val)
 	return false;
 }
 
+
 bool ObsDecoder::checkLevel(double level) 
 {
     if ( level == kBufrMissingValue ) return true; // Surface data ....
@@ -516,7 +591,8 @@ void ObsDecoder::getInfo(const std::set<string>& tokens, multimap<string, string
 {
 	MvObsSet obsSet(file_name_.c_str());
 
-	for (std::set<string>::const_iterator token = tokens.begin(); token != tokens.end(); ++token) {
+	for (std::set<string>::const_iterator token = tokens.begin(); token != tokens.end(); ++token)
+	{
 		std::set<string> noduplicate;
 		string value;
 		try {
@@ -533,87 +609,99 @@ void ObsDecoder::getInfo(const std::set<string>& tokens, multimap<string, string
 			}
 		}
 		catch ( NoFactoryException) {}
-		for (std::set<string>::const_iterator no = noduplicate.begin(); no != noduplicate.end(); ++no) {
-					//Log::dev()<< *token << "--->" << *no << "\n";
-					// here we add it to the list, only if it is the obs_types_list! 
-					if ( findInTypes(*no) ) values.insert(make_pair(*token, *no));
+
+		for (std::set<string>::const_iterator no = noduplicate.begin(); no != noduplicate.end(); ++no)
+		{
+#ifdef OBS_DEBUG_
+			cout << " ObsDecoderToken: "<< *token << " -> " << *no << "\n";
+#endif
+			// here we add it to the list, only if it is the obs_types_list!
+			if ( findInTypes(*no) ) values.insert(make_pair(*token, *no));
 		}
 	}
 }
 
-
-
-
-void ObsDecoder::customisedPoints(const std::set<string>& tokens, CustomisedPointsList& values)
+/*!
+   For Each points ... create an CustomisedPoints using the tokens..
+   then add it to the list! 
+*/
+void ObsDecoder::customisedPoints(const Transformation& transformation, const std::set<string>& tokens, CustomisedPointsList& values)
 {
-	// For Each points ... create an CustomisedPoints using the tokens..
-	// then add it to the list! 
 	MvObsSet obsSet(file_name_.c_str());
 
 	// Test 
-	MvObsSetIterator   obsIterator(obsSet);
+	MvObsSetIterator obsIterator(obsSet);
 	MvObs obs = obsIterator();
 
 	ostringstream title;
-       
 	title << "Observation: " << obs.obsTime() << " [ type = " << obs.messageType() << " , subtype = " << obs.messageSubtype() << "]";
 	title_ = title.str();
-   
-    VectorOfPointers<vector<BufrAccessor*> > accessors;
-    for (std::set<string>::const_iterator token = tokens.begin(); token != tokens.end(); ++token) {
+#ifdef OBS_DEBUG_
+	cout << " ObsTitle: "<< title_ << "\n";
+#endif 
+	VectorOfPointers<vector<BufrAccessor*> > accessors;
+	for (std::set<string>::const_iterator token = tokens.begin(); token != tokens.end(); ++token)
+	{
 #ifdef MAGICS_EXCEPTION
-    	try {
-    		BufrAccessor* accessor = SimpleObjectMaker<BufrAccessor>::create(*token);
-    		accessors.push_back(accessor);
-    	}
-    	catch (NoFactoryException&) {
-    		Log::dev() << " No Specialised accessor for " << *token << ": take the default\n";
-    		BufrAccessor* accessor = new BufrAccessor(*token);
-    		accessors.push_back(accessor);
-    	}
+		try {
+    			BufrAccessor* accessor = SimpleObjectMaker<BufrAccessor>::create(*token);
+    			accessors.push_back(accessor);
+		}
+		catch (NoFactoryException&) {
+    			Log::dev() << " No Specialised accessor for " << *token << ": take the default\n";
+    			BufrAccessor* accessor = new BufrAccessor(*token);
+    			accessors.push_back(accessor);
+		}
 #else 
-    BufrAccessor* accessor = SimpleObjectMaker<BufrAccessor>::create(*token);
-    if (accessor) {
-        accessors.push_back(accessor);
-    }
-    else {
-            Log::dev() << " No Specialised accessor for " << *token << ": take the default\n";
-    		BufrAccessor* accessor = new BufrAccessor(*token);
-    		accessors.push_back(accessor);
-    	}
+		BufrAccessor* accessor = SimpleObjectMaker<BufrAccessor>::create(*token);
+		if (accessor)
+		{
+			accessors.push_back(accessor);
+		}
+		else
+		{
+			Log::dev() << " No Specialised accessor for " << *token << ": take the default\n";
+    			BufrAccessor* accessor = new BufrAccessor(*token);
+    			accessors.push_back(accessor);
+		}
 #endif
-    }
-    
-    // Create the type accessor!
-    BufrAccessor* type_accessor = SimpleObjectMaker<BufrAccessor>::create("type");
-    string type;
-    BufrAccessor* level_accessor = new BufrAccessor("pressure");
-    double level;
+	}
+
+	// Create the type accessor!
+	BufrAccessor* type_accessor = SimpleObjectMaker<BufrAccessor>::create("type");
+	string type;
+	BufrAccessor* level_accessor = new BufrAccessor("pressure");
+	double level;
     
 	while (obs)
 	{
-		
 		(*type_accessor)(*this, obs, type);
 		
-		if ( findInTypes(type) ) { 
-			
+		if ( findInTypes(type) )
+		{
 			(*level_accessor)(*this, obs, level);
-			if (multilevels_[obs.messageType()] == false || checkLevel(level) ) {
-								
-				MvLocation loc = obs.location();
-				double value;		
-				CustomisedPoint* point = new CustomisedPoint(loc.x(), loc.y(),  obs.findSomeIdent());		
+			if (multilevels_[obs.messageType()] == false || checkLevel(level) )
+			{				
+			   MvLocation loc = obs.location();
+			   double value;		
+			   GeoPoint geo(loc.x(), loc.y());
+			   if ( transformation.in(geo) ) {
+				   CustomisedPoint* point = new CustomisedPoint(loc.x(), loc.y(),  obs.findSomeIdent());		
 				
-			    for (VectorOfPointers<vector<BufrAccessor*> >::const_iterator accessor = accessors.begin(); accessor != accessors.end(); ++accessor) {
-			    	(**accessor)(*this, obs, value);	    
-			    	if (value != kBufrMissingValue)  (*point)[(*accessor)->keyword()] = value;
-			    }
-				if ( !(*point).empty()) {
-					TFmiTime date = obs.msgTime();
-					(*point)["time"] = date.GetHour()*100 + date.GetMin();
-					values.push_back(point);
-				}
-				else delete point;
+				   for (VectorOfPointers<vector<BufrAccessor*> >::const_iterator accessor = accessors.begin(); accessor != accessors.end(); ++accessor)
+				   {
+					   (**accessor)(*this, obs, value);	    
+					   if (value != kBufrMissingValue)  (*point)[(*accessor)->keyword()] = value;
+				   }
+				   if ( !(*point).empty())
+				   {
+					   TMetTime date = obs.msgTime();
+					   (*point)["time"] = date.GetHour()*100 + date.GetMin();
+					   	values.push_back(point);
+				   }
+				   else 
+					   delete point;
+			   }
 			}
 		}
 		obs = obsIterator();
