@@ -30,7 +30,7 @@
 #include <Layer.h>
 #include <Polyline.h>
 #include <Text.h>
-
+#include <BinaryObject.h>
 #include <Colour.h>
 #include <Arrow.h>
 #include <Flag.h>
@@ -62,7 +62,7 @@ BaseDriver::BaseDriver():currentPage_(-1),fileName_(""),currentLayer_(""),curren
         currentLineType_(M_SOLID),currentLineWidth_(-1), currentLineStyle_(1),currentColour_(Colour("white")),
 	coordRatioX_(1),coordRatioY_(1),
 	lastAreaHeightPercentage_(0.),lastAreaWidthPercentage_(0.),
-	newPage_(true),newLayout_(true),disabled_(false),alphaEnabled_(false),polylineAntialiasing_(false),
+	newPage_(true),newLayout_(true),external_(false),polylineAntialiasing_(false),disabled_(false),alphaEnabled_(false),obs_distance_(-1.),
 	indexHatch_(0),currentShading_(M_SH_NONE),cmScale_(1.),
 	xDeviceLength_(Translator<double, double>().magics("SUPER_PAGE_X_LENGTH")),
 	yDeviceLength_(Translator<double, double>().magics("SUPER_PAGE_Y_LENGTH"))
@@ -110,8 +110,10 @@ BaseDriver::BaseDriver():currentPage_(-1),fileName_(""),currentLayer_(""),curren
 
 BaseDriver::~BaseDriver()
 {
+  FontMap_.clear();
 }
 
+
 //! Method set solid fill shading properties
 /*
  \sa renderSimplePolygon
@@ -244,6 +246,8 @@ string BaseDriver::getFileName(const string &extension, const unsigned int no) c
 	// name stays the same as given
 	if( no==0 && (full || (legacy && extension=="ps")) ) return filename;
 	if( no==0 )  { filename += ext; return filename;}
+	if( external_ )   { filename += "_legend"+ext; return filename;}
+
 
 	// if nothing is set
 	if(filename=="") filename = "magics";
@@ -301,23 +305,250 @@ MAGICS_NO_EXPORT void BaseDriver::redisplay(const Layer& layer) const
 		layer.visit(*this);
 }
 
+
+/*!
+ \brief Method to read and execute binary file
+ 
+ This method is implmented for performance in Metview 4 and WREP
+ 
+*/
+void BaseDriver::redisplay(const BinaryObject& binary) const 
+{
+  ifstream in(binary.getPath().c_str());
+  char mag [6];
+  in.read((char *)(&mag), 6);
+  if(strncmp( "MAGICS", mag,6) !=0 )
+  {
+	  Log::error() << "Magics number of binary file " <<binary.getPath().c_str()<<" is wrong!\n"
+			<< "   Please check endiness and if you gave the write filename."<< endl;
+	  return;
+  }
+  int version;
+  in.read((char *)(&version), sizeof(int));
+  cout << "BINARY version = "<<version<< endl;
+
+  char c;
+  while( in.get(c) )
+  {
+	int n;
+	switch(c) {
+	case 'T':
+        	float x;
+        	float y;
+        	float s;
+		int len;
+		{ 
+			in.read((char *)(&x), sizeof(float));
+			in.read((char *)(&y), sizeof(float));
+			Text text;
+			PaperPoint pp(x,y);
+			text.push_back(pp);
+
+			float angle;
+			in.read((char *)(&angle), sizeof(float));
+			in.read((char *)(&s), sizeof(float));
+			bool bl;
+			in.read((char *)(&bl), sizeof(bool));
+			enum Justification horizontal;
+			enum VerticalAlign vertical;
+			in.read((char *)(&horizontal), sizeof(enum Justification));
+			in.read((char *)(&vertical), sizeof(enum VerticalAlign));
+			in.read((char *)(&len), sizeof(int));
+			char *tex = new char[len+1];
+			in.read(tex, sizeof(char)*len);
+			tex[len]='\0';
+
+			string str(tex);
+			text.addText(str,Colour("black"),s);
+			text.setBlanking(bl);
+			text.setJustification(horizontal);
+			text.setVerticalAlign(vertical);
+			text.setAngle(angle);
+			renderText(text);
+			delete [] tex;
+		}
+        	break;
+
+	case 'A':
+        	in.read((char *)(&n), sizeof(int));
+        	{
+			Arrow arrow;
+			double sc;
+			in.read((char *)(&sc), sizeof(double));
+			arrow.setScale(sc);
+			int index;
+			in.read((char *)(&index), sizeof(int));
+			arrow.setHeadIndex(index);
+			LineStyle ls;
+			in.read((char *)(&ls), sizeof(LineStyle));
+			arrow.setStyle(ls);
+			ArrowPosition ap;
+			in.read((char *)(&ap), sizeof(ArrowPosition));
+			arrow.setArrowPosition(ap);
+			int hi;
+			in.read((char *)(&hi), sizeof(int));
+			arrow.setHeadIndex(hi);
+			double hr;
+			in.read((char *)(&hr), sizeof(double));
+			arrow.setHeadRatio(hr);
+			float r,g,b;
+			in.read((char *)(&r), sizeof(float));
+			in.read((char *)(&g), sizeof(float));
+			in.read((char *)(&b), sizeof(float));
+			setNewColour(Colour(r,g,b));
+
+			for(int pts=0;pts<n;pts++)
+			{
+			  double x,y;
+			  in.read((char *)(&x), sizeof(double));
+			  in.read((char *)(&y), sizeof(double));
+			  PaperPoint p;
+			  in.read((char *)(&p), sizeof(PaperPoint));
+			  ArrowPoint ap(x, y, p);
+			  arrow.push_back(ap);
+			} 
+			renderWindArrow(arrow);
+		}
+		break;
+	case 'H':
+		in.read((char *)(&n), sizeof(int));
+		{
+			float *x = new float[n];
+			float *y = new float[n];
+			in.read((char *)(x), sizeof(float)*n);
+			in.read((char *)(y), sizeof(float)*n);
+			renderPolyline( n, x, y);
+			delete [] x;
+			delete [] y;
+		}
+		break;
+
+	case 'B':
+		in.read((char *)(&n), sizeof(int));
+		{
+			float *x = new float[n];
+			float *y = new float[n];
+			in.read((char *)(x), sizeof(float)*n);
+			in.read((char *)(y), sizeof(float)*n);
+			renderPolyline2( n, x, y);
+			delete [] x;
+			delete [] y;
+		}
+		break;
+
+	case 'S':
+        	in.read((char *)(&n), sizeof(int));
+        	{
+			float *x = new float[n];
+			float *y = new float[n];
+			in.read((char *)(x), sizeof(float)*n);
+			in.read((char *)(y), sizeof(float)*n);
+			renderSimplePolygon( n, x, y);
+			delete [] x;
+			delete [] y;
+		}
+        	break;
+
+	case 'W':
+        	float width;
+        	in.read((char *)(&width), sizeof(float));
+        	setNewLineWidth(width);
+        	break;
+
+	case 'L':
+        	float w;
+        	LineStyle linestyle;
+        	in.read((char *)(&linestyle), sizeof(LineStyle));
+        	in.read((char *)(&w), sizeof(float));
+        	setLineParameters(linestyle, w);
+        	break;
+
+	case 'C':
+        	float r,g,b;
+        	in.read((char *)(&r), sizeof(float));
+        	in.read((char *)(&g), sizeof(float));
+        	in.read((char *)(&b), sizeof(float));
+        	setNewColour(Colour(r,g,b));
+        	break;
+	case 'N':
+	//		  cout<<"N"<< endl;
+        	startPage();
+        	break;
+	case 'E':
+	//		  cout<<"E"<< endl;
+        	endPage();
+        	break;
+	case 'P':
+		{
+			Layout l;
+			double x,y,w,h,minx,miny,maxx,maxy;
+			in.read((char *)(&x), sizeof(double));
+			in.read((char *)(&y), sizeof(double));
+			in.read((char *)(&w), sizeof(double));
+			in.read((char *)(&h), sizeof(double));
+			in.read((char *)(&minx), sizeof(double));
+			in.read((char *)(&miny), sizeof(double));
+			in.read((char *)(&maxx), sizeof(double));
+			in.read((char *)(&maxy), sizeof(double));
+			l.x(x);
+			l.y(y);
+			l.width(w);
+			l.height(h);
+			l.minX(minx);
+			l.minY(miny);
+			l.maxX(maxx);
+			l.maxY(maxy);
+			project(l);
+		}
+        	break;
+	case 'U':
+        	unproject();
+        	break;
+	}
+   }
+   in.close();
+}
+
+
 /*!
   \brief processing layouts
   This methods processes the Layout objects. It needs to be checked if a Layout is a new page or not.
-  \sa Layout UnLayout
+  \sa Layout
 */
 MAGICS_NO_EXPORT void BaseDriver::redisplay(const Layout& layout) const 
 {
 	if(layout.childOfRoot()) startPage();  // New page detected
 
 	project(layout);
-
 	staLayouts_.push(&layout);
-
 	layout.visit(*this);  // visit this layout!
 	unproject();
 
-	if(layout.childOfRoot())  endPage();
+	if(layout.childOfRoot())
+	{
+		endPage();
+		vecPoints_.clear();
+	}
+}
+
+/*!
+  \brief processing standalone layouts
+  This methods processes the Layout objects. It will mostly requires a new page!
+  Only the KMLDriver will have the legend included.
+  \sa Layout UnLayout
+*/
+void BaseDriver::redisplay(const StandaloneLayout& layout) const
+{
+	external_=true;
+	startAdditionalPage(layout);  // New page detected
+
+	project(layout);
+	staLayouts_.push(&layout);
+	layout.visit(*this);  // visit this layout!
+	unproject();
+
+	endAdditionalPage();
+        external_=false;
 }
 
 MAGICS_NO_EXPORT void BaseDriver::redisplay(const RootLayout& root) const
@@ -371,7 +602,6 @@ void BaseDriver::redisplay(const Image& object) const
 
 void BaseDriver::redisplay(const Text& text) const
 {
-	
 	renderText(text);
 }
 
@@ -382,13 +612,11 @@ void BaseDriver::redisplay(const Symbol& symbol) const
 
 void BaseDriver::redisplay(const TextSymbol& symbol) const 
 {
-	
 	renderTextSymbols(symbol);
 }
 
 void BaseDriver::redisplay(const ComplexSymbol& symbol) const 
 {
-	
 	renderComplexSymbols(symbol);
 }
 
@@ -533,7 +761,7 @@ void BaseDriver::printLine(const Polyline &line) const
                 float pro_y = y[i+2];  // lines not needed
                 // end of line fitting
 		
-		Text text;
+                Text text;
 		PaperPoint pp(pro_x,pro_y);		
 		text.push_back(pp);
 
@@ -560,6 +788,7 @@ void BaseDriver::printLine(const Polyline &line) const
 
     delete [] x;
     delete [] y;
+
     currentColour_ = Colour("none");
 }
 
