@@ -102,11 +102,15 @@ void CairoDriver::open()
         Log::info() << "Cairo version used is: "<<cairo_version_string()<< " backend: "<<backend_ <<endl;
 
         const float ratio = getYDeviceLength() / getXDeviceLength();
-	const int width = getWidth();
+	const int width = maground(getWidth());
 
 	setCMscale(float(width)/getXDeviceLength());
 	dimensionXglobal_ = width;
-	dimensionYglobal_ = static_cast<int>(ratio*width);
+	Log::dev() << "width -->" << width << endl;
+	Log::dev() << "ratio -->" << ratio*width << endl;
+	Log::dev() << "ratio -->" << maground(ratio*width) << endl;
+	Log::dev() << "ratio -->" << static_cast<int>(ratio*width) << endl;
+	dimensionYglobal_ = maground(ratio*width);
 
 	coordRatioY_ = -1;
 
@@ -121,7 +125,14 @@ void CairoDriver::open()
 		Log::error() << "CairoDriver: For contexts you need at least Cairo 1.2!" <<endl;
 #endif
 	}
-	else if(magCompare(backend_,"png"))
+	else
+		setupNewSurface();
+}
+
+
+void CairoDriver::setupNewSurface() const
+{
+	if(magCompare(backend_,"png"))
 	{
 	    surface_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, dimensionXglobal_, dimensionYglobal_);
 	}
@@ -269,12 +280,15 @@ void CairoDriver::open()
 	cairo_paint (cr_);
 	cairo_set_line_join(cr_,CAIRO_LINE_JOIN_BEVEL);
 
-        dimensionX_ = static_cast<float>(dimensionXglobal_);
-        if(!context_)
-            dimensionY_ = static_cast<float>(dimensionYglobal_);
-        else
-            dimensionY_ =  static_cast<int>(ratio*dimensionXglobal_);
-        currentPage_ = 0;
+	dimensionX_ = static_cast<float>(dimensionXglobal_);
+	if(!context_)
+	   dimensionY_ = static_cast<float>(dimensionYglobal_);
+	else
+	{
+	   const float ratio = getYDeviceLength() / getXDeviceLength();
+	   dimensionY_ =  static_cast<int>(ratio*dimensionXglobal_);
+	}
+	currentPage_ = 0;
 }
 
 /*!
@@ -307,6 +321,7 @@ void CairoDriver::close()
 #endif
 }
 
+
 /*!
   \brief starting a new page
 
@@ -372,6 +387,41 @@ MAGICS_NO_EXPORT void CairoDriver::startPage() const
 	newPage_ = true;
 }
 
+MAGICS_NO_EXPORT void CairoDriver::startAdditionalPage(const StandaloneLayout& lay) const
+{
+	if (magCompare(backend_,"png") )
+	{
+		tmp_cr_ = cr_;
+		tmp_surface_ = surface_;
+
+		surface_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, lay.outputWidth(),lay.outputHeight());
+		cr_ = cairo_create(surface_);
+
+		if(magCompare(getTransparent(),"off"))
+		{
+			cairo_set_source_rgb (cr_, 1.0, 1.0, 1.0); /* white */
+		}
+		else
+		{
+			cairo_set_source_rgba (cr_, 1.0, 1.0, 1.0, 0.0); /* white */
+		}
+		cairo_paint (cr_);
+	}
+}
+
+MAGICS_NO_EXPORT void CairoDriver::endAdditionalPage() const
+{
+	filename_ = getFileName("png" ,-2);
+	cairo_surface_write_to_png(surface_, filename_.c_str());
+	if(!filename_.empty()) printOutputName("CAIRO png "+filename_);
+	cairo_destroy (cr_);
+	cairo_surface_destroy (surface_);
+	surface_=tmp_surface_;
+	cr_=tmp_cr_;
+}
+
+
+
 /*!
   \brief ending a new page
 
@@ -380,24 +430,16 @@ MAGICS_NO_EXPORT void CairoDriver::startPage() const
 */
 MAGICS_NO_EXPORT void CairoDriver::endPage() const
 {
-	if( magCompare(backend_,"pdf") || magCompare(backend_,"ps") )
+	cairo_show_page(cr_);
+
+	if(magCompare(backend_,"eps"))
 	{
-		cairo_show_page(cr_);
-	}
-	else if(magCompare(backend_,"eps"))
-	{
-		cairo_show_page(cr_);
 		if(!filename_.empty()) printOutputName("CAIRO eps "+filename_);
 	}
 	else if(magCompare(backend_,"svg"))
 	{
-		cairo_show_page(cr_);
 		if(!filename_.empty()) printOutputName("CAIRO svg "+filename_);
 	}
-	else if(magCompare(backend_,"cairo"))
-	{
-		cairo_show_page(cr_);
-	}
 	else if (magCompare(backend_,"png") )
 	{
 		filename_ = getFileName("png" ,currentPage_);
@@ -499,13 +541,32 @@ MAGICS_NO_EXPORT void CairoDriver::unproject() const
   This colour stays the default drawing colour until the painting in the
   current box is finished.
 
-  \sa Colour
+  \sa Colour setColour
 */
 MAGICS_NO_EXPORT void CairoDriver::setNewColour(const Colour &colour) const
 {
 	currentColour_ = colour;
 }
 
+/*!
+  \brief sets a colour
+
+  This colour stays the default drawing colour until the painting in the
+  current box is finished.
+
+  \sa Colour setNewColour
+*/
+MAGICS_NO_EXPORT void CairoDriver::setColour(cairo_t* cr, const Colour &colour) const
+{
+	if(!(colour=="undefined") && ( (colour.red()*colour.green()*colour.blue()) >= 0 ) )
+	{
+	  if(colour.alpha()<1.) cairo_set_source_rgb (cr,colour.red(),colour.green(),colour.blue());
+	  else                  cairo_set_source_rgba(cr,colour.red(),colour.green(),colour.blue(),colour.alpha());
+	}
+	else cairo_set_source_rgba(cr,1.,1.,1.,0.);
+}
+
+
 /*!
   \brief sets a new line width
 
@@ -517,7 +578,7 @@ MAGICS_NO_EXPORT void CairoDriver::setNewColour(const Colour &colour) const
 */
 MAGICS_NO_EXPORT void CairoDriver::setNewLineWidth(const float width) const
 {
-        currentLineWidth_ = width * .6;
+        currentLineWidth_ = (width > 0.01 ? width : 0.01) * .6;
 }
 
 /*!
@@ -554,12 +615,12 @@ MAGICS_NO_EXPORT int CairoDriver::setLineParameters(const LineStyle linestyle, c
 		case M_CHAIN_DASH: // 4 on - 2 off -  1 on - 2 off
 			static double chain_dash_line[] = { 4., 4., 0., 6. };
 			cairo_set_line_cap (cr_, CAIRO_LINE_CAP_SQUARE);
-			cairo_set_dash(cr_,chain_dash_line,4,0);
+			cairo_set_dash(cr_,chain_dash_line,4,0.);
 			break;
 		case M_CHAIN_DOT: // 4 on - 2 off -  1 on - 2 off - 1 on - 2 off
 			static double chain_dot_line[] = { 4., 4., 0., 6., 0., 6. };
 			cairo_set_line_cap (cr_, CAIRO_LINE_CAP_SQUARE);
-			cairo_set_dash(cr_,chain_dot_line,6,0);
+			cairo_set_dash(cr_,chain_dot_line,6,0.);
 			break;
 		default:  // SOLID
 			cairo_set_line_cap (cr_, CAIRO_LINE_CAP_SQUARE);
@@ -601,8 +662,8 @@ MAGICS_NO_EXPORT void CairoDriver::renderPolyline(const int n, float *x, float *
 
 	cairo_identity_matrix (cr_);
         cairo_set_line_width (cr_, currentLineWidth_);
-	cairo_set_source_rgb(cr_,currentColour_.red(),currentColour_.green(),currentColour_.blue());
-        cairo_stroke (cr_);
+	setColour(cr_,currentColour_);
+	cairo_stroke (cr_);
 	cairo_restore(cr_);
 }
 
@@ -627,8 +688,8 @@ MAGICS_NO_EXPORT void CairoDriver::renderPolyline2(const int n, float* x, float*
 	cairo_identity_matrix (cr_);
 	cairo_set_line_width (cr_, currentLineWidth_);
 
-	cairo_set_source_rgb(cr_,currentColour_.red(),currentColour_.green(),currentColour_.blue());
-        cairo_stroke (cr_);
+	setColour(cr_, currentColour_);
+	cairo_stroke (cr_);
 	cairo_restore(cr_);
 }
 
@@ -647,7 +708,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon(const int n, float* x, fl
 {
 	if(n<3) return;
 	cairo_save(cr_);
-	cairo_set_source_rgb(cr_,currentColour_.red(),currentColour_.green(),currentColour_.blue());
+	setColour(cr_, currentColour_);
 
 	float xx = projectX(x[0]);
 	float yy = projectY(y[0]);
@@ -677,7 +738,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon(const int n, float* x, fl
 		cr2 = cairo_create (pat_surface);
 		cairo_surface_destroy (pat_surface);
 
-		cairo_set_source_rgb(cr2,currentColour_.red(),currentColour_.green(),currentColour_.blue());
+		setColour(cr2, currentColour_);
 		const float off = (density-s)*.5;
 		cairo_rectangle (cr2, off, off, off+s, off+s);
 		cairo_fill (cr2);
@@ -706,7 +767,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon(const int n, float* x, fl
 		cr2 = cairo_create (pat_surface);
 		cairo_surface_destroy (pat_surface);
 
-		cairo_set_source_rgb(cr2,currentColour_.red(),currentColour_.green(),currentColour_.blue());
+		setColour(cr2, currentColour_);
 		if(indexHatch_==1 || indexHatch_==3) // horizontal
 		{
 			cairo_move_to(cr2,       0, density*.5+.5);
@@ -828,7 +889,11 @@ MAGICS_NO_EXPORT void CairoDriver::renderText(const Text& text) const
 	char * pText = 0;
 
 	pango_parse_markup(glyphs, len, 0, &pAttrList, &pText, NULL, &pError);
-	if(pError) Log::warning() << "PANGO: " <<pError->message<<"<"<< endl;
+	if(pError)
+	{
+	  Log::warning() << "PANGO: " <<pError->message<<"<"<< endl;
+//	  free(pError);
+	}
 
 	PangoLayout *layout = pango_cairo_create_layout(cr_);
 	pango_layout_set_text (layout, pText, -1);
@@ -870,6 +935,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderText(const Text& text) const
 	  pango_cairo_show_layout (cr_, layout);
 	  cairo_restore(cr_);
 	}
+
 //	cairo_restore(cr_);
 }
 
@@ -898,12 +964,16 @@ MAGICS_NO_EXPORT void CairoDriver::circle(const float x, const float y, const fl
 	cairo_save(cr_);
 	cairo_new_sub_path(cr_);
 
+//	cairo_identity_matrix (cr_);
+	cairo_set_line_width (cr_, currentLineWidth_);
+	setColour(cr_, currentColour_);
+
 	int fill = s;
 
 	if(s > 8) fill = 8;
 	if(s > 0)
 	{
-		cairo_arc (cr_, xx, yy, r, 0, M_PI * 2. * fill / 8.);
+		cairo_arc (cr_, xx, yy, r, -M_PI * .5, M_PI * ((0.25 * fill)-.5) );
 		cairo_fill(cr_);
 	}
 
@@ -913,10 +983,10 @@ MAGICS_NO_EXPORT void CairoDriver::circle(const float x, const float y, const fl
 		cairo_move_to (cr_, xx, yy+r-1);
 		cairo_line_to (cr_, xx, yy-r+1);
 	        cairo_stroke(cr_);
-		cairo_set_source_rgb(cr_,currentColour_.red(),currentColour_.green(),currentColour_.blue());
+		setColour(cr_, currentColour_);
 	}
 
-	cairo_arc (cr_, xx, yy, r, 0, M_PI * 2.);
+	cairo_arc (cr_, xx, yy, r, 0., M_PI * 2.);
         cairo_stroke(cr_);
 	cairo_restore(cr_);
 #else
@@ -944,6 +1014,9 @@ MAGICS_NO_EXPORT void CairoDriver::circle(const float x, const float y, const fl
 MAGICS_NO_EXPORT bool CairoDriver::renderPixmap(float x0,float y0,float x1,float y1,
                   int w,int h,unsigned char* pixmap,int,bool alpha) const
 {
+#ifdef DRIVERS_DEBUG_
+	cout << "CD:renderPixmap> "<<w<<"x"<<h << endl;
+#endif
 	unsigned char *p = pixmap;
 	const float dx =  (x1 - x0)/w;
 	const float dy = -(y1 - y0)/h;   // Minus needed for Y axis correction
@@ -952,6 +1025,9 @@ MAGICS_NO_EXPORT bool CairoDriver::renderPixmap(float x0,float y0,float x1,float
 	const float Y0 = y0;
 	float a=0;
 
+	cairo_save(cr_);
+	cairo_antialias_t t = cairo_get_antialias(cr_);
+	cairo_set_antialias(cr_, CAIRO_ANTIALIAS_NONE);
 	for(int i=h-1;i>=0;i--)
 	{
 		for(int j=0;j<w; x0+=dx,j++)
@@ -965,17 +1041,22 @@ MAGICS_NO_EXPORT bool CairoDriver::renderPixmap(float x0,float y0,float x1,float
 			{
 				if (!alpha) cairo_set_source_rgb(cr_,r,g,b);
 				else        cairo_set_source_rgba(cr_,r,g,b,a);
-
-                                const float x0 = X0+(j*dx);
-                                const float y0 = Y0+(i*dy);
-				cairo_rectangle (cr_, x0,y0,dx,-dy);
-				cairo_stroke_preserve(cr_);
-				cairo_fill (cr_);
 			}
+			else
+				cairo_set_source_rgba(cr_,1,1,1,0);
+
+
+			const float x0 = X0+(j*dx);
+			const float y0 = Y0+(i*dy);
+			cairo_rectangle (cr_, x0,y0,dx,-dy);
+			cairo_stroke_preserve(cr_);
+			cairo_fill (cr_);
 		}
 		x0 = X0;
 		y0 += dy;
 	}
+	cairo_restore(cr_);
+	cairo_set_antialias(cr_, t);
 	return true;
 }
 
@@ -1041,6 +1122,10 @@ MAGICS_NO_EXPORT void CairoDriver::renderImage(const ImportObject& obj) const
 */
 MAGICS_NO_EXPORT bool CairoDriver::renderCellArray(const Image& image) const
 {
+#ifdef DRIVERS_DEBUG_
+	cout << "CD:renderCellArray> "<<image.getWidth()<<"x"<<image.getHeight() << endl;
+#endif
+
 	ColourTable &lt = image.getColourTable();
 	const int width  = image.getNumberOfColumns();
 	const int height = image.getNumberOfRows();
@@ -1051,6 +1136,9 @@ MAGICS_NO_EXPORT bool CairoDriver::renderCellArray(const Image& image) const
 	const float dx = (x1-x0)/width;
 	const float dy = -(y1-y0)/height;
 
+	cairo_save(cr_);
+	cairo_antialias_t t = cairo_get_antialias(cr_);
+	cairo_set_antialias(cr_, CAIRO_ANTIALIAS_NONE);
 	for (int i=height-1;i>=0;i--)
 	{
 		for(int j=0;j<width; j++)
@@ -1058,17 +1146,16 @@ MAGICS_NO_EXPORT bool CairoDriver::renderCellArray(const Image& image) const
 		  const long in = width*i+j;
 		  const short c = image[in];
 
- 		  if(!(lt[c]=="undefined") && ( (lt[c].red()*lt[c].green()*lt[c].blue()) >= 0 ) )
-		  {
-			cairo_set_source_rgb(cr_,lt[c].red(),lt[c].green(),lt[c].blue());
-                        const float wx = x0+(j*dx);
-                        const float wy = y0+(i*dy);
-			cairo_rectangle (cr_,wx,wy,dx,dy);
-			cairo_stroke_preserve(cr_);
-			cairo_fill (cr_);
-		  }// point has colour
+		  setColour(cr_,Colour(lt[c].red(),lt[c].green(),lt[c].blue(),lt[c].alpha()));
+		  const float wx = x0+(j*dx);
+		  const float wy = y0+(i*dy);
+		  cairo_rectangle (cr_,wx,wy,dx,dy);
+		  cairo_stroke_preserve(cr_);
+		  cairo_fill (cr_);
 		}
 	}
+	cairo_restore(cr_);
+	cairo_set_antialias(cr_, t);
 	return true;
 }
 
