@@ -323,18 +323,18 @@ MAGICS_NO_EXPORT void KMLDriver::redisplay(const Layer& layer) const
 {
   if(!magCompare("coastlines",layer.name()) || getCoastlines() )
   {
-	if(!magCompare(currentLayer_,layer.name()))
-	{
+//	if(!magCompare(currentLayer_,layer.name()))
+//	{
 		currentLayer_     = layer.name();
 		currentTimeBegin_ = layer.kmlTimeBegin();
 		currentTimeEnd_   = layer.kmlTimeEnd();
-		
+cout << "layer "<<layer.name()<<" "<<layer.kmlTimeBegin()<< endl;		
 		newLayer();
 		layer.visit(*this);
 		closeLayer();
-	}
-	else
-		layer.visit(*this);
+//	}
+//	else
+//		layer.visit(*this);
   }
 }
 
@@ -767,7 +767,7 @@ Log::dev()<< "KML driver Image import uses GD -> for better results use Cairo ba
 #else
 	stringstream out;
 	out << 15 * kml_output_resource_list_.size();
-	string filename = "overlay_"+out.str()+"png";
+	string filename = "KML_overlay_"+out.str()+"png";
 
 	pFile_	<< "<GroundOverlay>\n";
 	if(layer_)
@@ -862,6 +862,8 @@ Log::dev()<< "KML driver Image import uses GD -> for better results use Cairo ba
 	cairo_surface_write_to_png (surface_, filename.c_str());
 	cairo_destroy (cr_);
 	cairo_surface_destroy (surface_);
+	kml_output_resource_list_.push_back(filename);
+	pFile_	<< "</GroundOverlay>\n";
 #endif
    }
 	return true;
@@ -889,8 +891,8 @@ MAGICS_NO_EXPORT bool KMLDriver::renderCellArray(const Image& image) const
 Log::dev()<< "KML driver uses GD -> for better results use Cairo backend."<< endl;
 	stringstream out;
 	out << currentPage_;
-	const string layer_name = (!currentLayer_.empty()) ? currentLayer_ : "default_page"+out.str();
-	const string filename = "overlay_"+layer_name+".png";
+	const string layer_name = (!currentLayer_.empty()) ? currentLayer_ : "default_page";
+	const string filename = "KML_cell_overlay_"+layer_name+"_"+out.str()+".png";
 
 	pFile_	<< "<GroundOverlay>\n";
 	if(layer_)
@@ -966,20 +968,19 @@ Log::dev()<< "KML driver uses GD -> for better results use Cairo backend."<< end
 	gdImageAlphaBlending(im, 1);
 	gdImageSaveAlpha(im, 1); // save transparency
 
-	kml_output_resource_list_.push_back(filename);
-
 	FILE *outFile = fopen(filename.c_str(),"wb");
 	gdImagePng(im,outFile);
 	fclose(outFile);
 	gdImageDestroy(im);
+	kml_output_resource_list_.push_back(filename);
 
 	pFile_	<< "</GroundOverlay>\n";
 #endif
 #else
 	stringstream out;
 	out << currentPage_;
-	const string layer_name = (!currentLayer_.empty()) ? currentLayer_ : "default_page"+out.str();
-	string filename = "overlay_"+layer_name+".png";
+	const string layer_name = (!currentLayer_.empty()) ? currentLayer_ : "default_page";
+	string filename = "KML_cell_overlay_"+layer_name+"_"+out.str()+".png";
 	string::size_type loc=0;
 
 	while(loc != string::npos)
