@@ -200,8 +200,8 @@ MAGICS_NO_EXPORT void PostScriptDriver::startPage() const
 	*ps << "gs " << 72./getResolution() << " dup s ";
 if(old_)
 {
-	if( isEPS() && (getXDeviceLength() < getYDeviceLength()) ||
-	   !isEPS() && (getXDeviceLength() > getYDeviceLength()))
+	if( ( isEPS() && (getXDeviceLength() < getYDeviceLength()) ) ||
+	    (!isEPS() && (getXDeviceLength() > getYDeviceLength()) ) )
 		*ps << static_cast<int>(dimensionY_) << " 0 t 90 ro ";
 }
 	*ps << "1 lw [] 0 sd ";
@@ -237,6 +237,8 @@ MAGICS_NO_EXPORT void PostScriptDriver::project(const magics::Layout& layout) co
 {
 	debugOutput("Begin layout "+layout.name());
 
+	Log::debug() << "---> PROJECT (PS) " << layout.name() <<  endl;
+
 	float scale = 1.0;
 	if(newPage_) {scale = getScale();newPage_=false;}
 
@@ -271,6 +273,7 @@ MAGICS_NO_EXPORT void PostScriptDriver::project(const magics::Layout& layout) co
 //	if(fabs(X_) > 0.0001 && fabs(Y_) > 0.0001 )
 		*ps<<" "<< X_ <<" "<< Y_ <<" t";
 	*ps	<<"\n";
+
 }
 
 /*!
@@ -483,7 +486,7 @@ MAGICS_NO_EXPORT void PostScriptDriver::renderPolyline(const int n, float *x, fl
 
 		while(nn>1)
 		{
-			unsigned int p = ( nn > maxPathSize_) ? maxPathSize_ : nn;
+			unsigned int p = ( nn > int(maxPathSize_)) ? maxPathSize_ : nn;
 			dx = new float[p+1];
 			dy = new float[p+1];
 
