@@ -107,9 +107,10 @@ using namespace magics;
   \brief Constructor
 */
 SVGDriver::SVGDriver() : groupString_(""),
-			showCoordinates_(false),line_group_(false),
-			interactive_(false),interactiveCounter_(0)
+			group_counter_(0), showCoordinates_(false),
+			interactive_(false),line_visible_(true), interactiveCounter_(0)
 {
+  inkscape_=true;
 }
 
 /*!
@@ -141,7 +142,7 @@ void SVGDriver::close()
 */
 MAGICS_NO_EXPORT void SVGDriver::startPage() const
 {
-Log::debug() <<"SVG start PAGE "<<endl;
+	debugOutput("Page - START");
 	dimensionX_ = getWidth();
 	dimensionY_ = dimensionX_*getRatio();
 	const int height = static_cast<int>(dimensionY_);
@@ -152,15 +153,17 @@ setCMscale(30.);
 	currentPage_++;
 
 	string filename = getFileName("svg",currentPage_+1);
+	tmp_pFile_ = filename;
 
 	pFile_.open(filename.c_str(),std::ios::out);
 	svg_output_resource_list_.push_back(filename);
 
 	if(!pFile_)
 	{
-		Log::fatal() << "SVGDriver::startPage() --> Cannot open SVG output file!" << filename << "\n";
+		Log::fatal() << "SVGDriver::startPage() --> Cannot open SVG output file: " << filename << "\n";
 		exit(1);
 	}
+//	pFile_ = org_pFile_;
 	// pFile_.precision(3);
 	// pFile_.setf(ios_base::fixed);
 
@@ -172,6 +175,12 @@ setCMscale(30.);
 	<< "xmlns=\"http://www.w3.org/2000/svg\"\n"
 	<< "xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n"
 	<< "xmlns:ev=\"http://www.w3.org/2001/xml-events\"\n";
+
+	if(inkscape_)
+	  pFile_ << "xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\"\n"
+	         << "xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\"\n"
+	         << "inkscape:version=\"0.46\"\n"
+	         << "inkscape:output_extension=\"org.inkscape.output.svg.inkscape\"\n";
 	
 	if(getWriteSize()) pFile_<< "width=\""<<width<<"px\" height=\""<<height<<"px\" "; 
 
@@ -195,6 +204,54 @@ setCMscale(30.);
 	pFile_<< "<g id=\"page\" transform=\"translate(0,"<<dimensionY_<<")\">\n";
 }
 
+MAGICS_NO_EXPORT void SVGDriver::startAdditionalPage(const StandaloneLayout& lay) const
+{
+	debugOutput("Extra page - START");
+
+	pFile_.close();
+	string fn = getFileName("svg" ,-2);
+	pFile_.open(fn.c_str(),std::ios::out);
+
+	if(!pFile_)
+	{
+		Log::fatal() << "SVGDriver::startAdditionalPage() --> Cannot open SVG output file for legend: " << lay.path() << "\n";
+		exit(1);
+	}
+	svg_output_resource_list_.push_back(lay.path());
+
+	pFile_
+	<< "<svg version=\"1.1\" encoding=\"iso-8859-1\" baseProfile=\"full\"\n"
+	<< "xmlns=\"http://www.w3.org/2000/svg\"\n"
+	<< "xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n"
+	<< "xmlns:ev=\"http://www.w3.org/2001/xml-events\"\n";
+
+	if(inkscape_)
+	  pFile_ << "xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\"\n"
+		 << "xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\"\n"
+		 << "inkscape:version=\"0.46\"\n"
+		 << "inkscape:output_extension=\"org.inkscape.output.svg.inkscape\"\n";
+
+//	if(getWriteSize()) pFile_<< "width=\""<<width<<"px\" height=\""<<height<<"px\" ";
+
+	pFile_<< "viewBox=\"0 0 "<<lay.outputWidth()+1<<" "<<lay.outputHeight()+1<<"\"\n"
+	<< "xml:space=\"preserve\"\n" // preserveAspectRatio=\"xMidYMid meet\"\n"
+//	<< "shape-rendering=\"optimizeSpeed\" text-rendering=\"optimizeSpeed\""
+	<< "zoomAndPan=\"enable\" >\n"
+	<< "<title>"<<getTitle()<<" Legend</title>\n";
+
+	pFile_<< "<g id=\"page\" transform=\"translate(0,"<<lay.outputHeight()<<")\">\n";
+}
+
+MAGICS_NO_EXPORT void SVGDriver::endAdditionalPage() const
+{
+	pFile_ << "</g></svg>\n";
+	pFile_.close();
+
+	pFile_.open(tmp_pFile_.c_str(),std::ios::app);
+	debugOutput("Extra page - END");
+}
+
+
 /*!
   \brief ending a page
  
@@ -203,7 +260,8 @@ setCMscale(30.);
 */
 MAGICS_NO_EXPORT void SVGDriver::endPage() const
 {
-Log::debug() <<"end PAGE "<<endl;
+	group_counter_=0;
+	debugOutput("Page - END");
 	// needed for y-axis translation in beginning!
 	pFile_	<< "</g>\n";  // end of Menu 
 
@@ -418,7 +476,7 @@ Log::debug() <<"end PAGE "<<endl;
 */
 MAGICS_NO_EXPORT void SVGDriver::project(const magics::Layout& layout) const
 {
-	debugOutput("Begin of layout - "+layout.name());
+	debugOutput("Layout - "+layout.name()+" START");
 Log::debug() <<"PROJECT "<<layout.name()<<" "<<dimensionX_<<" w: "<< layout.width()<<" x: "<< layout.x()<< endl;
 	dimensionStack_.push(dimensionX_);
 	dimensionStack_.push(dimensionY_);
@@ -445,12 +503,23 @@ Log::debug() <<"PROJECT "<<layout.name()<<" "<<dimensionX_<<" w: "<< layout.widt
 //			<< " <path d=\"M"<<projectX(Xmin)<<" "<<projectY(-Ymin)<<"l"<< projectX(sumX)<<" 0l0 "<<-projectY(sumY)<<"l"<<-projectX(sumX)<<" 0l0 "<<projectY(sumY)<<"\"/>\n"
 //			<< "</clipPath>\n"; 
 //	}
-	pFile_ << "<g transform=\"translate("<< Xoff+projectX(-layout.minX())<<","<< setY(Yoff+projectY(-layout.minY()))<<")\"";
+const float x_set = Xoff+projectX(-layout.minX());
+const float y_set = Yoff+projectY(-layout.minY());
+
+group_counter_++;
+
+if(group_counter_>2)
+{
+        pFile_ << "<g id=\""<<layout.name()<<"\" transform=\"translate("<<x_set <<","<<setY(y_set) <<")\"";
 
 //	if(showCoordinates_ && area=="drawing_area") pFile_ << " onmouseover=\"setLonScale("<<coordRatioX_<<");showCoords(evt)\"";
 
 //	if(box->getClip()) pFile_ << " clip-path=\"url(#clip_"<<area<<")\"";
 	pFile_ << ">\n";
+//	group_project_=true;
+}
+//else
+//  group_project_=false;
 
 //	if(showCoordinates_ && area=="drawing_area")
 //		pFile_	<< "<rect x=\""<<Xmin<<"px\" y=\""<<setY(-Ymin)<<"px\" width=\""<<sumX<<"px\" height=\""<<sumY<<"px\" fill=\"white\"/>\n";
@@ -459,98 +528,17 @@ Log::debug() <<"PROJECT "<<layout.name()<<" "<<dimensionX_<<" w: "<< layout.widt
 MAGICS_NO_EXPORT void SVGDriver::unproject() const
 {
 	closeGroup();
-	closeLineGroup();
 
 	dimensionY_ = dimensionStack_.top();dimensionStack_.pop();
 	dimensionX_ = dimensionStack_.top();dimensionStack_.pop();
 	coordRatioX_  = scalesX_.top();scalesX_.pop();
 	coordRatioY_  = scalesY_.top();scalesY_.pop();
-	pFile_ << "</g>\n";
-
-	debugOutput("END Layout");
-}
-
-
-/*!
-  \brief project into a box
-
-  This method will update the offset and scale to position for new box.
-  The properties of boxes are stored in the current Layout.
-
-  \sa Layout
-*/
-//MAGICS_NO_EXPORT void SVGDriver::projectBox(const string& area) const
-//{
-/*	if(magCompare(currentBox_,area)) return;
-
-	if(newLayout_) newLayout_=false;
-	else unprojectBox();
-
-	currentBox_ = area;
-	debugOutput("Start box "+area);
-	Box *box = getBox(area);
-
-	const float Xoff	= dimensionX_ * box->getX()	* 0.01;
-	const float Yoff	= dimensionY_ * box->getY()	* 0.01;
-	const float Xlength	= dimensionX_ * box->getWidth() * 0.01;
-	const float Ylength	= dimensionY_ * box->getHeight()* 0.01;
-	const float Xmin	= box->getXmin();
-	const float Xmax	= box->getXmax();
-	const float Ymin	= box->getYmin();
-	const float Ymax	= box->getYmax();
-	const float sumX	= Xmax - Xmin;
-	const float sumY	= Ymax - Ymin;
-
-	scalesX_.push(coordRatioX_);
-	scalesY_.push(coordRatioY_);
-	coordRatioX_ *= Xlength/sumX;
-	coordRatioY_ *= Ylength/sumY;
-
-	if(box->getClip())
-	{
-		pFile_	<< "<clipPath id=\"clip_"<<area<<"\">\n"
-			<< " <path d=\"M"<<projectX(Xmin)<<" "<<projectY(-Ymin)<<"l"<< projectX(sumX)<<" 0l0 "<<-projectY(sumY)<<"l"<<-projectX(sumX)<<" 0l0 "<<projectY(sumY)<<"\"/>\n"
-			<< "</clipPath>\n"; 
-	}
-	pFile_ << "<g id=\""<<area<<"\" transform=\"translate("<< Xoff+projectX(-Xmin)<<","<< setY(Yoff+projectY(-Ymin))<<")\"";
-
-	if(showCoordinates_ && area=="drawing_area") pFile_ << " onmouseover=\"setLonScale("<<coordRatioX_<<");showCoords(evt)\"";
-
-	if(box->getClip()) pFile_ << " clip-path=\"url(#clip_"<<area<<")\"";
-	pFile_ << ">\n";
-
-	if(showCoordinates_ && area=="drawing_area")
-		pFile_	<< "<rect x=\""<<Xmin<<"px\" y=\""<<setY(-Ymin)<<"px\" width=\""<<sumX<<"px\" height=\""<<sumY<<"px\" fill=\"white\"/>\n";
-}
-*/
-/*!
-  \brief unproject into a box
-
-  This method will update the offset and scale to rest from the current box.
-  The properties of boxes are stored in the current Layout.
-
-  \sa Layout
-*/
-/*
-MAGICS_NO_EXPORT void SVGDriver::unprojectBox() const
-{
-	if(currentBox_=="non") return;
-
-	closeGroup();
-	closeLineGroup();
-
-	if(scalesX_.size()>1)
-	{
-		coordRatioX_  = scalesX_.top();
-		scalesX_.pop();
-		coordRatioY_  = scalesY_.top();
-		scalesY_.pop();
+	if(group_counter_>2)
 		pFile_ << "</g>\n";
-	}
-	currentBox_="non";
-	debugOutput("Finish Box");
+	group_counter_--;
+	debugOutput("Layout - END");
 }
-*/
+
 
 /*!
   \brief setup a new layer
@@ -560,8 +548,13 @@ MAGICS_NO_EXPORT void SVGDriver::unprojectBox() const
 */
 MAGICS_NO_EXPORT void SVGDriver::newLayer(const Layer& ) const
 {
-	debugOutput("Start Layer - "+currentLayer_);
-	pFile_ << "<g id=\""<<currentLayer_<<"\">\n";
+	closeGroup();
+
+	debugOutput("Layer - "+currentLayer_+" START");
+	pFile_ << "<g ";
+	if(inkscape_)
+	  pFile_ << "inkscape:groupmode=\"layer\" inkscape:label=\""<<currentLayer_<<"\" ";
+	pFile_ << "id=\""<<currentLayer_<<"\">\n";
 	layers_.push_back(currentLayer_);
 }
 
@@ -574,9 +567,9 @@ MAGICS_NO_EXPORT void SVGDriver::newLayer(const Layer& ) const
 MAGICS_NO_EXPORT void SVGDriver::closeLayer(const Layer& ) const
 {
 	closeGroup();
-	closeLineGroup();
 
 	pFile_ << "</g>\n";
+	debugOutput("Layer - "+currentLayer_+" END");
 }
 
 //MAGICS_NO_EXPORT void SVGDriver::renderInteractiveBegin(const InteractiveBegin& interactive) const
@@ -590,7 +583,6 @@ MAGICS_NO_EXPORT void SVGDriver::closeLayer(const Layer& ) const
 	}
 */
 /*	closeGroup();
-	closeLineGroup();
 
 	if( !magCompare(currentBox_,"non") ) unprojectBox();
 	debugOutput("renderInteractiveBegin");
@@ -607,22 +599,13 @@ MAGICS_NO_EXPORT void SVGDriver::renderInteractiveEnd(const InteractiveEnd&) con
 	interactive_=false;
 }
 */
-MAGICS_NO_EXPORT void SVGDriver::closeLineGroup() const
-{
-	if(line_group_)
-	{
-		pFile_	<< "</g>"<<endl;
-		debugOutput("Close line group");
-		line_group_ = false;
-	}
-}
 
 MAGICS_NO_EXPORT void SVGDriver::openGroup(string g) const
 {
 	if(!magCompare(g,groupString_))
 	{
 		closeGroup();
-		pFile_	<< g <<endl;
+		pFile_	<< "<g "<<g<<" >" <<endl;
 		groupString_ = g;
 	}
 }
@@ -679,29 +662,33 @@ MAGICS_NO_EXPORT void SVGDriver::setNewLineWidth(const float width) const
 MAGICS_NO_EXPORT int SVGDriver::setLineParameters(const LineStyle linestyle, const float w) const
 {
 	const float wid = w*0.5;
-	if( line_group_ && (currentLineType_ == linestyle && wid == currentLineWidth_) ) return 0;
-	currentLineType_ = linestyle;
-	setNewLineWidth(wid);
-	closeGroup();
-	closeLineGroup();
-
 	const float widi = (wid > 1) ? wid : 1;
+	currentLineType_ = linestyle;
 
-	debugOutput("Open line group");
-	pFile_  << "<g stroke-width=\""<<wid<<"px\" ";
-	
-//	if(!interactive_) pFile_  << "pointer-events=\"none\" ";
-	
-	pFile_  << "stroke=\"rgb("
-		<< static_cast<int>(currentColour_.red()  *255) << ","
-		<< static_cast<int>(currentColour_.green()*255) << ","
-		<< static_cast<int>(currentColour_.blue() *255) << ")\" fill=\"none\"";
-		if(currentLineType_==M_DASH)            pFile_  << " stroke-dasharray=\""<<2*widi<<","<<2*widi<<"\"";
-		else if(currentLineType_==M_DOT)        pFile_  << " stroke-dasharray=\""<<1*widi<<","<<2*widi<<"\"";
-		else if(currentLineType_==M_CHAIN_DASH) pFile_  << " stroke-dasharray=\""<<4*widi<<","<<2*widi<<","<<2*widi<<","<<2*widi<<"\"";
-		else if(currentLineType_==M_CHAIN_DOT)  pFile_  << " stroke-dasharray=\""<<4*widi<<","<<2*widi<<","<<2*widi<<","<<2*widi<<","<<2*widi<<"\"";
-	pFile_	<< ">\n";
-	line_group_ = true;
+	ostringstream stream;
+	stream  << "stroke-width=\""<<wid<<"px\" ";
+	if(currentColour_.red()*currentColour_.green()*currentColour_.blue()<0)
+	{
+		stream	<< "stroke=\"none\"";
+		line_visible_=false;
+	}
+	else
+	{
+		line_visible_=true;
+		if(currentColour_.alpha() < 1.) stream	<< "stroke-opacity=\""<<currentColour_.alpha()<<"\" ";
+		stream	<< "stroke=\"rgb("
+			<< static_cast<int>(currentColour_.red()  *255) << ","
+			<< static_cast<int>(currentColour_.green()*255) << ","
+			<< static_cast<int>(currentColour_.blue() *255) << ")\"";
+	}
+	stream  << " fill=\"none\"";
+
+	if(currentLineType_==M_DASH)            stream  << " stroke-dasharray=\""<<2*widi<<","<<2*widi<<"\"";
+	else if(currentLineType_==M_DOT)        stream  << " stroke-dasharray=\""<<1*widi<<","<<2*widi<<"\"";
+	else if(currentLineType_==M_CHAIN_DASH) stream  << " stroke-dasharray=\""<<4*widi<<","<<2*widi<<","<<2*widi<<","<<2*widi<<"\"";
+	else if(currentLineType_==M_CHAIN_DOT)  stream  << " stroke-dasharray=\""<<4*widi<<","<<2*widi<<","<<2*widi<<","<<2*widi<<","<<2*widi<<"\"";
+
+	openGroup(stream.str());
 	return 0;
 }
 
@@ -720,6 +707,7 @@ MAGICS_NO_EXPORT int SVGDriver::setLineParameters(const LineStyle linestyle, con
 */
 MAGICS_NO_EXPORT void SVGDriver::renderPolyline(const int n, float *x, float *y) const
 {
+  if(!line_visible_) return;
   if(n>1)
   {
 	float old_x = projectX(x[0]);
@@ -755,6 +743,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderPolyline(const int n, float *x, float *y)
 */
 MAGICS_NO_EXPORT void SVGDriver::renderPolyline2(const int n, float* x, float* y) const
 {
+	if(!line_visible_) return;
 	if(n != 2) return;
 	pFile_ << "<path d=\"M"<<x[0]<< " " <<setY(y[0])<<"L"<< x[1] <<" "<< setY(y[1]) << "\" />\n";
 }
@@ -772,16 +761,16 @@ MAGICS_NO_EXPORT void SVGDriver::renderPolyline2(const int n, float* x, float* y
 */
 MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, float* x, float* y) const
 {
-	closeLineGroup();
+	closeGroup();
 	debugOutput("renderSimplePolygon");
 	if(n<2) return;
+	if(currentColour_.red()*currentColour_.green()*currentColour_.blue()<0) return;
 
-	ostringstream stream;
 	int count = 1;
-
 	float old_x = projectX(x[0]);
 	float old_y = setY(projectY(y[0]));
 	
+	ostringstream stream;
 	stream  <<" d=\"M"<<old_x<< " " << old_y;
 
 	for(int is=1;is<n;is++)
@@ -810,7 +799,9 @@ MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, float* x, floa
 			        << "   <rect x=\"3\" y=\"3\" width=\"3\" height=\"3\" stroke=\"none\" fill=\"rgb("
 				<< static_cast<int>(currentColour_.red()  *255) << ","
 				<< static_cast<int>(currentColour_.green()*255) << ","
-				<< static_cast<int>(currentColour_.blue() *255) << ")\" />\n"
+				<< static_cast<int>(currentColour_.blue() *255) << ")\" ";
+			if(currentColour_.alpha() < 1.) pFile_	<< "fill-opacity=\""<<currentColour_.alpha()<<"\" ";
+			pFile_  << "/>\n"
 			        << "</pattern>\n"
 			        << "<path fill=\"url(#D_"<<svg_pattern_count<<")\" stroke=\"none\" "
 				<< stream.str() <<"\" />\n";
@@ -881,8 +872,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, float* x, floa
 MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const
 {
   if(text.empty()) return;
-  closeLineGroup();
-  
+
   float text_scale = 0.6;  // for Firefox 2
 
   const vector<NiceText>& niceT = text.getNiceText();
@@ -932,19 +922,24 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const
 
 		if(niceText==text.textBegin())
 		{
-		 if(tex==0)
-		 {
-		  pFile_ << "<g text-anchor=\""<<justification<< "\"";
-		  if(text.getAngle()!=0) pFile_ << " transform=\"rotate("<<text.getAngle()*57.29577951<<","<<xxx<<","<<yyy<<")\"";
-		  pFile_ <<" font-size=\""<<dheight<<"cm\" font-family=\""<< ttf << "\" "
-//		      <<"stroke=\"rgb("<<currentColour_.red()*255<<","<<currentColour_.green()*255<<","<<currentColour_.blue()*255<<")\" "
-		      <<"fill=\"rgb("<<static_cast<int>(currentColour_.red()*255)<<","<<static_cast<int>(currentColour_.green()*255)<<","
-                      << static_cast<int>(currentColour_.blue()*255)<<")\">";
-		 }
-		 pFile_ << "<text x=\""<<xxx<<"\" y=\""<<yyy<<"\"";
-		 if(text.getBlanking()) pFile_ << " background-color=\"white\"";
-	//	 pFile_ << " baseline-shift=\""<<vertical<<"%\">"<<(*niceText).text();
-		 pFile_ << "><tspan dy=\""<<vertical<<"cm\">"<<(*niceText).text()<<"</tspan>";
+		   if(tex==0)
+		   {
+			ostringstream stream;
+			stream  << "text-anchor=\""<<justification<< "\"";
+			if(text.getAngle()!=0)
+				stream << " transform=\"rotate("<<text.getAngle()*57.29577951<<","<<xxx<<","<<yyy<<")\"";
+			stream <<" font-size=\""<<dheight<<"cm\" font-family=\""<< ttf << "\" "
+//			       <<"stroke=\"rgb("<<currentColour_.red()*255<<","<<currentColour_.green()*255<<","<<currentColour_.blue()*255<<")\" "
+			       <<"fill=\"rgb("<<static_cast<int>(currentColour_.red()*255)<<","<<static_cast<int>(currentColour_.green()*255)<<","
+			       << static_cast<int>(currentColour_.blue()*255)<<")\"";
+			openGroup(stream.str());
+		   }
+
+		   pFile_ << "<text x=\""<<xxx<<"\" y=\""<<yyy<<"\"";
+		   if(text.getBlanking())
+			   pFile_ << " background-color=\"white\"";
+	//	   pFile_ << " baseline-shift=\""<<vertical<<"%\">"<<(*niceText).text();
+		   pFile_ << "><tspan dy=\""<<vertical<<"cm\">"<<(*niceText).text()<<"</tspan>";
 		}
 		else
 		{
@@ -958,7 +953,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const
 	}// end for all strings
 	pFile_ <<"</text>\n";
    }// end for all co-ordinates
-   pFile_ <<"</g>\n";
+//   pFile_ <<"</g>\n";
 }
 
 /*!
@@ -977,31 +972,66 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const
 */
 MAGICS_NO_EXPORT void SVGDriver::circle(const float x, const float y, const float r, const int s) const
 {
-	const int cx = static_cast<int>(projectX(x));
+	const int cx =      static_cast<int>(projectX(x));
 	const int cy = setY(static_cast<int>(projectY(y)));
 
-	if(s < 8 && s > 0)
-	{
-		const short i   = (s<4) ? 1 : 0;
-		const float rad = s*0.7853981634*r;
-		pFile_	<< "<path d=\"M"<<cx<<" "<<cy<<"l 0 -"<<r<<" A"<<r<<" "<<r<<" 0 "<<i<<" 1 "
-			<< cx+cos(rad)<<" "<<cy+sin(rad)<<"\" />\n"
-			<< "<circle cx=\""<<cx<<"\" cy=\""<<cy<<"\" r=\""<<r<<"\" stroke=\"rgb("
-			<< static_cast<int>(currentColour_.red()  *255) << ","
-			<< static_cast<int>(currentColour_.green()*255) << ","
-			<< static_cast<int>(currentColour_.blue() *255) << ")\" "
-			<< "fill=\"none\" />\n";
-	}
-	else	pFile_	<< "<circle cx=\""<<cx<<"\" cy=\""<<cy<<"\" r=\""<<r<<"\" fill=\"rgb("
-			<< static_cast<int>(currentColour_.red()  *255) << ","
-			<< static_cast<int>(currentColour_.green()*255) << ","
-			<< static_cast<int>(currentColour_.blue() *255) << ")\" "
-			<<"stroke=\"rgb("
-			<< static_cast<int>(currentColour_.red()  *255) << ","
-			<< static_cast<int>(currentColour_.green()*255) << ","
-			<< static_cast<int>(currentColour_.blue() *255) << ")\" />\n";
+	ostringstream stream;
 
-	if(s==9) Log::error() << "SVGDRIVER: fill 9 on circle needs implementing!"<< endl;
+	if(s < 8 && s >= 0)
+	{
+		stream  << "stroke=\"rgb("
+			<< static_cast<int>(currentColour_.red()  *255) << ","
+			<< static_cast<int>(currentColour_.green()*255) << ","
+			<< static_cast<int>(currentColour_.blue() *255) << ")\""
+			<< " fill=\"none\"";
+		openGroup(stream.str());
+
+		if(s==0)
+		{
+		 pFile_	<< "<circle cx=\""<<cx<<"\" cy=\""<<cy<<"\" r=\""<<r<<"\"/>\n";
+		}
+		else
+		{
+		 const short  i   = (s<4) ? 1 : 0;
+		 const double rad = s*0.7853981634*r;
+		 pFile_	<< "<path d=\"M"<<cx<<" "<<cy-r<<" A"<<r<<","<<r<<" 0 "<<i<<" 1 "
+			<< cx+cos(rad)<<" "<<cy+sin(rad)<<"\" "
+			<< "fill=\"rgb("
+			<< static_cast<int>(currentColour_.red()  *255) << ","
+			<< static_cast<int>(currentColour_.green()*255) << ","
+			<< static_cast<int>(currentColour_.blue() *255) << ")\""
+			<<"/>\n"
+			<< "<circle cx=\""<<cx<<"\" cy=\""<<cy<<"\" r=\""<<r<<"\"""/>\n";
+		}
+	}
+	else if(s==8)
+	{
+		stream  << "stroke=\"rgb("
+			<< static_cast<int>(currentColour_.red()  *255) << ","
+			<< static_cast<int>(currentColour_.green()*255) << ","
+			<< static_cast<int>(currentColour_.blue() *255) << ")\""
+			<< " fill=\"rgb("
+			<< static_cast<int>(currentColour_.red()  *255) << ","
+			<< static_cast<int>(currentColour_.green()*255) << ","
+			<< static_cast<int>(currentColour_.blue() *255) << ")\"";
+		openGroup(stream.str());
+
+		pFile_	<< "<circle cx=\""<<cx<<"\" cy=\""<<cy<<"\" r=\""<<r<<"\"/>\n";
+	}
+	if(s==9)
+	{
+		stream  << "stroke=\"rgb("
+			<< static_cast<int>(currentColour_.red()  *255) << ","
+			<< static_cast<int>(currentColour_.green()*255) << ","
+			<< static_cast<int>(currentColour_.blue() *255) << ")\""
+			<< " fill=\"rgb("
+			<< static_cast<int>(currentColour_.red()  *255) << ","
+			<< static_cast<int>(currentColour_.green()*255) << ","
+			<< static_cast<int>(currentColour_.blue() *255) << ")\"";
+		openGroup(stream.str());
+		pFile_	<< "<circle cx=\""<<cx<<"\" cy=\""<<cy<<"\" r=\""<<r<<"\"/>\n"
+			<< "<polyline points=\"0,"<<r*.9<<" 0,"<<-r*.9<<"\" width=\"2\" stroke=\"white\" fill=\"white\"/>"<<endl;
+	}
 
 }
 
@@ -1019,7 +1049,6 @@ MAGICS_NO_EXPORT void SVGDriver::circle(const float x, const float y, const floa
   \param w width of pixmap
   \param h height of pixmap
   \param pixmap contents
-  \param landscape says if contents is landscape
 
 */
 MAGICS_NO_EXPORT bool SVGDriver::renderPixmap(float x0,float y0,float x1,float y1,
@@ -1032,7 +1061,7 @@ MAGICS_NO_EXPORT bool SVGDriver::renderPixmap(float x0,float y0,float x1,float y
 	const float X0 = x0;
 	const float Y0 = y0;
 
-	debugOutput("Start pixmap");
+	debugOutput("Pixmap - START");
 	pFile_	<< "<g pointer-events=\"none\" >\n";
 
 	for(int i=h-1;i>=0;i--)
@@ -1053,6 +1082,7 @@ MAGICS_NO_EXPORT bool SVGDriver::renderPixmap(float x0,float y0,float x1,float y
 		y0 += dy;
 	}
 	pFile_	<< "</g>\n";
+	debugOutput("Pixmap - END");
 	return true;
 }
 
@@ -1074,7 +1104,7 @@ MAGICS_NO_EXPORT bool SVGDriver::renderCellArray(const Image& image) const
 	const float x0 = projectX(image.getOrigin().x());
 	const float y0 = projectY(image.getOrigin().y());
 
-	debugOutput("Start cell array");
+	debugOutput("Cell array - START");
 	pFile_	<< "<g pointer-events=\"none\" stroke=\"none\" >\n";
 
 #ifdef MAGICS_RASTER
@@ -1112,7 +1142,7 @@ else
 	stringstream out;
 	out << "page"<<currentPage_<<"_"<<currentLayer_;
 
-	string filename = "svg_include_"+out.str()+".png";
+	string filename = tmp_pFile_+"_include_"+out.str()+".png";
 
 	pFile_	<< "<image x=\""<<x0<<"\" y=\""<<setY(y0)<<"\" "
 		<< " width=\""<<projectX(image.getWidth())<<"\" height=\""<<projectY(image.getHeight())<<"\" "
@@ -1159,6 +1189,7 @@ else
 }
 #endif
 	pFile_	<< "</g>\n";
+	debugOutput("Cell array - END");
 	return true;
 }
 
@@ -1170,7 +1201,7 @@ else
 MAGICS_NO_EXPORT void SVGDriver::renderImage(const ImportObject& obj) const
 {
 Log::dev()<< "SVG-IMAGEOBJECT: "<<obj.getFormat()<<" "<<obj.getPath()<<" "<< obj.getOrigin().x()<<" "<<obj.getOrigin().y()<< endl;
-	closeLineGroup();
+	closeGroup();
 	std::string file = obj.getPath();
 
 	string format = obj.getFormat();
@@ -1241,19 +1272,20 @@ void SVGDriver::print(ostream& out)  const
 */
 MAGICS_NO_EXPORT void SVGDriver::renderSymbols(const Symbol& symbol) const
 {
-	debugOutput("Start symbols");
-	
+	debugOutput("Symbols - START");
+
+	closeGroup();
 	if(symbol.getSymbol()=="logo_ecmwf")
 	{
+	  if(inkscape_) pFile_ << "<g inkscape:groupmode=\"layer\" inkscape:label=\"ecmwf_logo\">\n";
 	  const string location = getLogoLocation();
 	  if(magCompare(location,"INLINE"))
-	  	BaseDriver::renderSymbols(symbol);
+		BaseDriver::renderSymbols(symbol);
 	  else
-	  {	
+	  {
 		const float x = projectX(symbol[0].x());
 		const float y = projectY(symbol[0].y());
 		closeGroup();
-		closeLineGroup();
 		string logofile;
 		if(magCompare(location,"WWW")) logofile = "http://www.ecmwf.int/publications/manuals/magics/magplus/resources/ecmwf_logo.png";
 		else if(magCompare(location,"LOCAL")) logofile = "ecmwf_logo.png";
@@ -1263,9 +1295,12 @@ svg_output_resource_list_.push_back(logofile);
 		       << "<image x=\""<<x-(y*1.35)<<"\" y=\""<<setY(y+(y*.5))<<"\" width=\""<<y*5.4<<"\" height=\""<<y<<"\" xlink:href=\""<<logofile<<"\" />"
 		       << "</a>\n";
 	  }
+	  if(inkscape_) pFile_ << "</g>\n";
 	}
 	else 
 		BaseDriver::renderSymbols(symbol);
+
+	debugOutput("Symbols - END");
 }
 
 static SimpleObjectMaker<SVGDriver, BaseDriver> SVG_driver("SVG");
