@@ -68,7 +68,7 @@ Akima760<P>::Akima760(const  AbstractMatrix& matrix, const Akima760MethodAttribu
 
       // Estimates partial derivatives at all input-grid data points
       //{
-      Timer timer("RGPD3P");
+      Timer timer("Akima", "Time spent in interpolation");
       rgpd3p();
       //}
       
