@@ -111,7 +111,7 @@ struct SortHelper
 
 void CoastPlotting::operator()(DrawingVisitor& parent)
 {
-	Timer timer("coastlines");
+	Timer timer("coastlines", "prepare the coastlines");
 	if ( !layer_) layer_ = &parent;
 	const Transformation& transformation = parent.transformation();
 	decode(parent);
