@@ -74,10 +74,10 @@ void tick(double min, double max, vector<double>& ticks)
 		log = log10(step);
 		ws = pow(10., int(log));
 		inc = ceil(step/ws)*ws;
-		Log::dev() << "Automatic method ---> increment = " << inc << " ---> try base=" << inc/ws << endl;
+		//Log::dev() << "Automatic method ---> increment = " << inc << " ---> try base=" << inc/ws << endl;
 			
 		if ( wmax-wmin != inc && (inc/ws == 1 || inc/ws == 2 || inc/ws == 5 || inc/ws == 10) ) {
-			Log::dev() << "Automatic method ---> increment " << inc << " OK! " << endl;
+			//Log::dev() << "Automatic method ---> increment " << inc << " OK! " << endl;
 			break;
 		}
 		nb++;	
@@ -387,7 +387,7 @@ public:
 		text->setFont(font_);
 		text->setJustification(MLEFT);
 		text->push_back(PaperPoint(x+1.5, y-0.2));
-		visitor.push_back(text);	
+		visitor.push_back(text);
 		text  = new Text();
 		text->setText("100%");
 		text->setFont(font_);
@@ -510,10 +510,8 @@ public:
 		ostringstream title;
 		// carefull here this text is depending of the resolution! 
 		Log::dev() << "EpsControl=>resolution" << resolution << endl; 
-		if ( type == "degrees" ) 
-			title << "EPS Control(110 km) ";
-		else 			
-			title << "EPS Control(50 km) ";
+        int km = maground(40000/(2*(resolution+1)+2));  
+		title << "EPS Control(" + tostring(km) + " km)";
 		title_ = title.str();
 	}
 	EpsControl(const string& title) : LegendEntry("") 
@@ -550,10 +548,8 @@ public:
 	{
 		Log::dev() << "EpsForecsat=>resolution" << resolution << endl; 
 		ostringstream title;
-		if ( type == "degrees" ) 
-			title << "High Resolution Deterministic(40 km) ";
-		else 			
-			title << "High Resolution Deterministic(25 km) ";
+        int km = maground(40000/(2*(2*resolution+1)+2));        
+		title << "High Resolution Deterministic(" + tostring(km) + " km)";
 		title_ = title.str();
 	}
 	
@@ -1436,9 +1432,9 @@ void EpsWave::operator()(Data<UserPoint>& data, BasicGraphicsObjectContainer& vi
 		directions["nord"] = 3.14 * 0.5 +3.14;
 		directions["nord_east"] = 3.14*0.25  +3.14;
 		directions["nord_west"] = 3.14*0.75 +3.14;
-		directions["svisitorh"] = 3.14*1.5 +3.14;
-		directions["svisitorh_east"] = 3.14*1.75 +3.14;
-		directions["svisitorh_west"] = 3.14*1.25 +3.14;
+		directions["south"] = 3.14*1.5 +3.14;
+		directions["south_east"] = 3.14*1.75 +3.14;
+		directions["south_west"] = 3.14*1.25 +3.14;
 		directions["west"] = 3.14 +3.14;
 //	}
 //	else {
@@ -1573,7 +1569,7 @@ void EfiGraph::operator()(Data<UserPoint>& data, BasicGraphicsObjectContainer& v
 				key << "clim_" << i;
 				map<string, double>::const_iterator step = (*point)->find(key.str());
 				if (step != (*point)->end() ) {
-                    Log::dev() << key.str() << ":" << step->second << "-->" << i << endl;
+                    //Log::dev() << key.str() << ":" << step->second << "-->" << i << endl;
 					efi->push_back(PaperPoint(step->second, i));
 					clim.push_back(step->second);
                 }
@@ -1648,7 +1644,7 @@ void EfiGraph::operator()(Data<UserPoint>& data, BasicGraphicsObjectContainer& v
 				key << step << "_" << i;
 				map<string, double>::const_iterator step = (*point)->find(key.str());
 				if (step != (*point)->end() ) {
-                    Log::dev() << key.str() << ":" << step->second << "-->" << i << endl;
+                    //Log::dev() << key.str() << ":" << step->second << "-->" << i << endl;
 					efi->push_back(PaperPoint(step->second, i));
                 }
 			}			
@@ -1968,7 +1964,7 @@ public:
 		
 	
 		
-        Colour colour("red");
+        Colour colour("grey");
         Polyline* median  = new Polyline();
 		median->setColour(colour);		
 		median->setLineStyle(M_SOLID);
@@ -2198,8 +2194,16 @@ void EpsPlume::operator()(Data<UserPoint>& data, BasicGraphicsObjectContainer& v
 		
 
 	map<string, Polyline* > lines;
-   
+	Polyline* control  = new Polyline();
+	control->setColour(*control_line_colour_);
+    control->setThickness(control_line_thickness_);
+    control->setLineStyle(control_line_style_);
 	
+    Polyline* forecast  = new Polyline();
+    	forecast->setColour(*forecast_line_colour_);
+        forecast->setThickness(forecast_line_thickness_);
+        forecast->setLineStyle(forecast_line_style_);
+    	
      
 	for (CustomisedPointsList::const_iterator point = points.begin(); point != points.end(); ++point) {
 		
@@ -2221,6 +2225,12 @@ void EpsPlume::operator()(Data<UserPoint>& data, BasicGraphicsObjectContainer& v
         		(iline->second)->push_back(PaperPoint(x, value->second));
 	        	
         	}
+        	
+        	if ( value->first == "forecast" ) 
+        		forecast->push_back(PaperPoint(x, value->second));
+        	if ( value->first == "control" ) 
+        		control->push_back(PaperPoint(x, value->second));
+        	
         }
         
        
@@ -2230,7 +2240,8 @@ void EpsPlume::operator()(Data<UserPoint>& data, BasicGraphicsObjectContainer& v
 	 for ( map<string, Polyline* >::const_iterator line = lines.begin(); line != lines.end(); ++line) {
 			visitor.push_back(line->second);
         }
-       
+	 visitor.push_back(control);
+	 visitor.push_back(forecast);
 }    
        
 	
