@@ -680,11 +680,14 @@ void IsoPlot<P>::isoline(Cell<P>& cell, CellBox<P>* box) {
 			if (*l == -1) continue; 
 			
 			double contour=levels_[*l];
+			
 			int out  = castab[cell.coef(m1, contour)][cell.coef(m2, contour)][cell.coef(m3, contour)];
+			
 			if ( out != 0 ) {
 				rused.push_back(*l);
 			}		
 		}
+	
 		
 		if ( rused.empty() && box ) {
 			Shape shape(this->shading_->colour(cell.value(m1)), cell.value(m1));
@@ -1341,16 +1344,38 @@ void IsoPlot<P>::isoline(MatrixHandler<P>& data, BasicGraphicsObjectContainer& p
 
 	const Transformation& transformation = parent.transformation();
 	levels_.clear();
+	// Find the used levels!
 	helper_ = map<double, vector<Polyline* > >();
 	const vector<double>::const_iterator end = (*this->levelSelection_).end();
-	levels_.push_back(data.min());
+	vector<double>::const_iterator previous = (*this->levelSelection_).end();
+	vector<double>::const_iterator last = (*this->levelSelection_).end();
+	
+	if ( (*this->levelSelection_).front()  > data.min() )
+		levels_.push_back(data.min());
 	
 	for (vector<double>::const_iterator l = (*this->levelSelection_).begin(); l != end; ++l) {
-		if ( (*l <= data.min()) || (*l >= data.max()))
+		if ( (*l <= data.min()) ) {
+			previous = l;
 			continue;
+		}
+		if ( (*l >= data.max()) ) {
+			       last = l;
+					continue;
+					
+		}
+		if ( previous != (*this->levelSelection_).end() ) {
+			 levels_.push_back(*previous);
+			 previous = (*this->levelSelection_).end();
+		}
 		levels_.push_back(*l);
 	}
-	levels_.push_back(data.max());
+	
+	if ( last != (*this->levelSelection_).end())
+				 levels_.push_back(*last);
+	else 
+		 levels_.push_back(data.max());
+				
+	
 	
 	missing_ = data.missing();
 
@@ -1388,7 +1413,7 @@ void IsoPlot<P>::isoline(MatrixHandler<P>& data, BasicGraphicsObjectContainer& p
 
 template<class P> bool IsoPlot<P>::prepare(MatrixHandler<P>& data) {
 	PointsHandler<P> points(data);
-
+	(*this->levelSelection_).clear();
 	(*this->levelSelection_).calculate(points.min() , points.max() , this->shading_->shadingMode());
 	(*this->label_).prepare(*this->levelSelection_, (*this->colour_).name());
 	return (*this->shading_)(*this->levelSelection_);
@@ -1402,7 +1427,7 @@ template<class P> void IsoPlot<P>::operator()(MatrixHandler<P>& data, BasicGraph
 	
 	prepare(data);
 	{
-		Timer timer("contouring");
+		Timer timer("contouring", "Time spent in contouring");
 		isoline(data, parent);
 	}
 	
@@ -1444,7 +1469,7 @@ template<class P> void NoIsoPlot<P>::operator()(MatrixHandler<P>& data, BasicGra
 	// The shading needs the isolines..
 	// WE will calculate them but will not send them to the printer     
 	{
-		Timer timer("contouring");
+		Timer timer("contouring", "Time spent in contouring");
 		isoline(data, parent);
 	}
 
