@@ -7,8 +7,8 @@
 
 int main()
 {
-	const char *formats[] = {"svg","kml","ps","pdf","eps","png"};
-	const num = 6;
+	const char *formats[] = {"svg","kml","ps","pdf","png"};
+	const int num = 5;
 
 	/* open magics and set the output device */
 	mag_open();
