@@ -5,7 +5,7 @@ C
       DIMENSION X(11),Y(11)
       DATA X/0.0,1.,2.,3.,4.,5.,6.,7.,8.,9.,10./
       DATA Y/0.0,4.,6.,8.,10.,15.,20.,30.,20.,10.,5./
-
+C
 C     OPEN MAGICS
 C 
       CALL POPEN
@@ -16,6 +16,7 @@ C
       CALL PSETC ('PAGE_ID_LINE_USER_TEXT', 'Printer test examples')
 C      
 C     dimensions for A3      
+C
       PX = 42.0
       PY = 29.7
       X1 =  0.5
@@ -27,14 +28,12 @@ C     Page locations. We have a 2x3 grid of plots
 C
       CALL PSETR('SUPER_PAGE_X_LENGTH',PX)
       CALL PSETR('SUPER_PAGE_Y_LENGTH',PY)
-
+C
       CALL PSETC ('SUBPAGE_MAP_PROJECTION', 'POLAR_STEREOGRAPHIC')
       CALL PSETR ('SUBPAGE_LOWER_LEFT_LATITUDE',    23.0)
       CALL PSETR ('SUBPAGE_LOWER_LEFT_LONGITUDE',  -33.0)
       CALL PSETR ('SUBPAGE_UPPER_RIGHT_LATITUDE',   51.0)
       CALL PSETR ('SUBPAGE_UPPER_RIGHT_LONGITUDE',  72.0)
-
-
 C
 C   Setup of subpages
 C      
@@ -45,28 +44,23 @@ C
       CALL PSETR ('PAGE_Y_LENGTH', 15.0)
       CALL PSETR ('PAGE_X_POSITION', X1)
       CALL PSETR ('PAGE_Y_POSITION', Y2)
-
-C     Set up our common plotting attributes
-c      CALL PSETC ('MAP_COASTLINE_LAND_SHADE',        'ON')
-c      CALL PSETC ('MAP_COASTLINE_LAND_SHADE_COLOUR', 'CREAM')
-      
+C
       CALL MAP_SHADING
-
+C
       CALL PCOAST
-
+C
       CALL PNEW  ('PAGE')
       CALL PSETR ('PAGE_X_POSITION', X2)
       CALL PSETR ('PAGE_Y_POSITION', Y2)
       CALL MAP_SHADING_2
-      
+C
       CALL PCOAST
-
+C
       CALL PNEW  ('PAGE')
       CALL PSETR ('PAGE_X_POSITION', X1)
       CALL PSETR ('PAGE_Y_POSITION', Y1)
       CALL MAP_THREE
-
-
+C
       CALL PNEW  ('PAGE')
       CALL PSETC ('PAGE_ID_LINE', 'OFF')
       CALL PSETR ('PAGE_X_POSITION', X2)
@@ -79,11 +73,11 @@ C
 C
       STOP
       END
-
-
+C
+C
       SUBROUTINE MAP_SHADING
-
-      PARAMETER (NLEV=17)
+C
+      PARAMETER (NLEV=18)
       CHARACTER*25 CTAB
       DIMENSION  CTAB  (NLEV)
       DATA       CTAB  /'BLUE_PURPLE',
@@ -102,11 +96,12 @@ C
      +                  'RED_ORANGE',
      +                  'ORANGISH_RED',
      +                  'RED',
+     +                  'REDDISH_PURPLE',
      +                  'MAGENTA'/
 C
 C     Pass the data to MAGICS
 C
-      CALL PSETC ('GRIB_INPUT_FILE_NAME', 'data/t2m_fc12.grib')
+      CALL PSETC ('GRIB_INPUT_FILE_NAME', '../data/t2m_fc12.grib')
       CALL PGRIB
       CALL PSETC  ('CONTOUR',                      'OFF')
       CALL PSETR  ('CONTOUR_SHADE_MIN_LEVEL',       -50.)
@@ -120,39 +115,27 @@ C
       CALL PSETC  ('CONTOUR_SHADE_METHOD',         'AREA_FILL')
       CALL PSETC  ('CONTOUR_HILO',                 'OFF')
       CALL PCONT
-
-
+C
       CALL PSETC ('GRIB_INPUT_FILE_NAME',
-     x  'data/wind30m_fc12.grib')
+     x  '../data/wind30m_fc12.grib')
       CALL PSETI ('GRIB_WIND_POSITION_1',1)                 
       CALL PSETI ('GRIB_WIND_POSITION_2',2) 
       CALL PGRIB
       CALL PWIND
-
-c      CALL PTEXT
-c
+C
       CALL PRESET('CONTOUR_SHADE_MIN_LEVEL')
       CALL PRESET('CONTOUR_SHADE_MAX_LEVEL')
-c
+C
       RETURN
       END
-
-
-
-
-
+C
+C
+C
       SUBROUTINE MAP_SHADING_2
-
-      PARAMETER (NLEV=20)
+C
+      PARAMETER (NLEV=21)
       CHARACTER*25 CTAB
       DIMENSION  CTAB  (NLEV)
-C      DATA       CTAB  /'RGB(0.57, 0.21, 0.04)',
-C     +                  'RGB(0.57, 0.21, 0.71)',
-C     +                  'RGB(0.65, 0.65, 0.97)',
-C     +                  'RGB(0.95, 0.95, 0.0)',
-C     +                  'RGB(0.8,  0.95, 0.37)',
-C     +                  'RGB(0.61, 0.78, 0.37)',
-C     +                  'RGB(0.46, 0.61, 0.37)'/
       DATA       CTAB  /'BLUISH_PURPLE',
      +                  'BLUE_PURPLE',
      +                  'PURPLISH_BLUE',
@@ -171,13 +154,14 @@ C     +                  'RGB(0.46, 0.61, 0.37)'/
      +                  'RED_ORANGE',
      +                  'ORANGISH_RED',
      +                  'RED',
-     +                  'MAGENTA',
+     +                  'REDDISH_PURPLE',
+     +                  'PURPLE_RED',
      +                  'MAGENTA'/
 C
 C     Pass the data to MAGICS
 C 
       CALL PSETC ('GRIB_INPUT_TYPE',      'FILE')
-      CALL PSETC ('GRIB_INPUT_FILE_NAME', 'data/t850_fc_12.grib')
+      CALL PSETC ('GRIB_INPUT_FILE_NAME', '../data/t850_fc_12.grib')
       CALL PGRIB
 C
       CALL PSETC  ('CONTOUR',                      'OFF')
@@ -192,10 +176,10 @@ C
       CALL PSETC  ('CONTOUR_SHADE_METHOD',         'AREA_FILL')
       CALL PSETC  ('CONTOUR_HILO',                 'OFF')
       CALL PCONT
-
+C
 C     Now load the Z500 data
-c
-      CALL PSETC ('GRIB_INPUT_FILE_NAME', 'data/z500_fc_12.grib')
+C
+      CALL PSETC ('GRIB_INPUT_FILE_NAME', '../data/z500_fc_12.grib')
       CALL PGRIB
 C     Redefine the contouring parameters for the Z500
       CALL PSETC  ('CONTOUR',                      'ON')
@@ -209,17 +193,15 @@ C     Redefine the contouring parameters for the Z500
       CALL PSETR  ('CONTOUR_HILO_SUPPRESS_RADIUS',  40.0)
       CALL PSETC  ('CONTOUR_SHADE',                'OFF')      
       CALL PCONT
-c
-c      CALL PTEXT
+C
       CALL PRESET('CONTOUR_SHADE_MIN_LEVEL')
       CALL PRESET('CONTOUR_SHADE_MAX_LEVEL')
-c
+C
       RETURN
       END
-
-
-
-
+C
+C
+C
       SUBROUTINE MAP_THREE
 C
       PARAMETER (NCOLS=64)
@@ -362,7 +344,7 @@ C     First, load and plot the temperature data, shaded
 C     Pass the data to MAGICS
 
       CALL PSETC ('GRIB_INPUT_TYPE',      'FILE')
-      CALL PSETC ('GRIB_INPUT_FILE_NAME', 'data/cloudcover.grib')
+      CALL PSETC ('GRIB_INPUT_FILE_NAME', '../data/cloudcover.grib')
       CALL PGRIB
 
 C     Set up the coastline attributes
@@ -395,17 +377,16 @@ C     Plot the title text and the coastlines
      +        CTAB(52) // '\\\ H+L,\\\CLBLACK\\\ H+M+L' //
      +        '\\\CLR\\\ clouds'
 C
-      CALL PSETR  ('TEXT_REFERENCE_CHARACTER_HEIGHT', 0.40)
+      CALL PSETR  ('TEXT_FONT_SIZE', 0.4)
       CALL PSETC  ('TEXT_LINE_1',TITLE)
       CALL PTEXT
       CALL PCOAST
 C
       RETURN
       END
-
-
-
-
+C
+C
+C
 	SUBROUTINE GRAPH_ONE
 C
 C	PLOT SIMPLE CURVE WITH SYMBOLS
@@ -458,21 +439,21 @@ c
 C
 C     Draw the boxplots using the default plotting attributes
 C
-      CALL PBOXPLOT
-      
-      CALL PSETC ('GRAPH_TYPE','BAR')
-      CALL PSETC ('GRAPH_SHADE','ON')
-      CALL PSETC ('GRAPH_SHADE_STYLE','HATCH')
-      CALL PSETI ('graph_shade_hatch_index',0)
-c
-      CALL PSETC ('GRAPH_SHADE_COLOUR','ORANGE')
+	CALL PBOXPLOT
+C      
+	CALL PSETC ('GRAPH_TYPE','BAR')
+	CALL PSETC ('GRAPH_SHADE','ON')
+	CALL PSETC ('GRAPH_SHADE_STYLE','HATCH')
+	CALL PSETI ('graph_shade_hatch_index',0)
+C
+	CALL PSETC ('GRAPH_SHADE_COLOUR','ORANGE')
 	CALL PSET1R ('GRAPH_BAR_X_VALUES',X2,10)
 	CALL PSET1R ('GRAPH_BAR_Y_LOWER_VALUES',YL,10)
 	CALL PSET1R ('GRAPH_BAR_Y_UPPER_VALUES',YU,10)
 	CALL PGRAPH
 C
 	CALL PSETC ('GRAPH_SHADE_STYLE','DOT')
-      CALL PSETC ('GRAPH_SHADE_COLOUR','BLUE')
+	CALL PSETC ('GRAPH_SHADE_COLOUR','BLUE')
 	CALL PSET1R ('GRAPH_BAR_X_VALUES',X2,10)
 	CALL PSET1R ('GRAPH_BAR_Y_LOWER_VALUES',YU,10)
 	CALL PSET1R ('GRAPH_BAR_Y_UPPER_VALUES',YU2,10)
